/**
* This file was autogenerated by kgendesignerplugin. Any changes will be lost!
* The generated code in this file is licensed under the same license that the
* input file.
*/
#include <QIcon>
#include <QtDesigner/QDesignerContainerExtension>
#if QT_VERSION >= 0x050500
# include <QtUiPlugin/QDesignerCustomWidgetInterface>
#else
# include <QDesignerCustomWidgetInterface>
#endif
#include <qplugin.h>
#include <qdebug.h>

#include <classpreviews.h>
#include <ktimezone.h>
#include <ktabbar.h>
#include <kdialog.h>
#include <krestrictedline.h>
#include <kdatewidget.h>
#include <keditlistbox.h>
#include <ktextbrowser.h>
#include <klistwidget.h>
#include <kbuttongroup.h>
#include <karrowbutton.h>
#include <kfontcombobox.h>
#include <kfilemetadatawidget.h>
#include <kcolordialog.h>
#include <kcolorvalueselector.h>
#include <knuminput.h>
#include <ktabwidget.h>
#include <kpushbutton.h>
#include <kcolordialog.h>
#include <kdatetimewidget.h>
#include <kdialogbuttonbox.h>
#include <knuminput.h>
#include <knuminput.h>
#include <k4timezonewidget.h>


class KTabBarPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KTabBarPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KTabBarPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/ktabbar.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Display (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("ktabbar.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KTabBar"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("KDE Tab Bar"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("A QTabBar with extended features."); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KTabBar( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDialogPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KDialogPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KDialogPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return true; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kdialog.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Container (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kdialog.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KDialog"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Class for simple Dialogs (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KDialog Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KDialogPreview( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KRestrictedLinePlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KRestrictedLinePlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KRestrictedLinePlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/krestrictedline.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("krestrictedline.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KRestrictedLine"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Line Edit for restricted input (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KRestrictedLine Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KRestrictedLine( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDateWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KDateWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KDateWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kdatewidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Date/Time (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kdatewidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KDateWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Date preview (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KDateWidget Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KDateWidget( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KEditListBoxPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KEditListBoxPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KEditListBoxPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/keditlistbox.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Views (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("keditlistbox.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KEditListBox"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Fullfeatured edit box with buttons (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KEditListBox Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KEditListBox( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KTextBrowserPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KTextBrowserPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KTextBrowserPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/ktextbrowser.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Display (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("ktextbrowser.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KTextBrowser"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Improved QTextBrowser (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("An improved version of the QTextBrowser with mail or system browser invocation support"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KTextBrowser( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KListWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KListWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KListWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/klistwidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Views (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("klistwidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KListWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Extended List Widget (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("An improved version of the QListWidget that follows KDE settings"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KListWidget( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KButtonGroupPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KButtonGroupPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KButtonGroupPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return true; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kbuttongroup.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Container (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kbuttongroup.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KButtonGroup"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Group of radio buttons with index selection."); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KButtonGroup Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KButtonGroup( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KArrowButtonPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KArrowButtonPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KArrowButtonPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/karrowbutton.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Buttons (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("karrowbutton.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KArrowButton"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Draws a button which shows an arrow pointing into a certain direction."); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KArrowButton Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KArrowButton(parent,Qt::UpArrow);
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KFontComboBoxPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KFontComboBoxPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KFontComboBoxPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kfontcombobox.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kfontcombobox.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KFontComboBox"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Font Combo Box (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("A combo box for font selection with language-specific previews"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KFontComboBox( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KFileMetaDataWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KFileMetaDataWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KFileMetaDataWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kfilemetadatawidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Display (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kfilemetadatawidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KFileMetaDataWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("File Meta Data Display"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("Shows the meta data of one or more file items."); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KFileMetaDataWidget( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KColorPatchPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KColorPatchPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KColorPatchPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kcolorpatch.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Display (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kcolordialog.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KColorPatch"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("The KColorPatch widget is a (usually small) widget showing a selected color."); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KColorPatch Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KColorPatch(parent);
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KColorValueSelectorPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KColorValueSelectorPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KColorValueSelectorPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kcolorvalueselector.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kcolorvalueselector.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KColorValueSelector"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Color Value Selector (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KColorValueSelector Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KColorValueSelector( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KIntSpinBoxPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KIntSpinBoxPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KIntSpinBoxPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kintspinbox.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("knuminput.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KIntSpinBox"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Enhanced Spinbox for Integer Values (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KIntSpinBox Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KIntSpinBox( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KTabWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KTabWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KTabWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return true; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/ktabwidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Container (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("ktabwidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KTabWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("KDE tab widget container."); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KTabWidget Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KTabWidget( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KPushButtonPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KPushButtonPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KPushButtonPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kpushbutton.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Buttons (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kpushbutton.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KPushButton"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Improved QPushButton (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("An improved QPushButton to follow KDE settings"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KPushButton( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KColorCellsPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KColorCellsPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KColorCellsPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kcolorcells.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kcolordialog.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KColorCells"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Color Table (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KColorCells Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KColorCells(parent, 3, 5);
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDateTimeWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KDateTimeWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KDateTimeWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kdatetimewidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Date/Time (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kdatetimewidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KDateTimeWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("This widget can be used to display or allow user selection of date and time. (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KDateTimeWidget Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KDateTimeWidget( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDialogButtonBoxPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KDialogButtonBoxPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KDialogButtonBoxPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kdialogbuttonbox.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QStringLiteral("<ui><widget class=\"KDialogButtonBox\"><property name=\"standardButtons\"><set>QDialogButtonBox::Ok|QDialogButtonBox::Cancel</set></property></widget></ui>"); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Buttons (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("kdialogbuttonbox.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KDialogButtonBox"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Button Box (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("KDE's button box."); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KDialogButtonBox( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDoubleNumInputPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KDoubleNumInputPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KDoubleNumInputPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kdoublenuminput.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("knuminput.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KDoubleNumInput"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Floating Point Number Input Widget (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("An input widget for floating point numbers, consisting of a spinbox and a slider."); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KDoubleNumInput( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KIntNumInputPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       KIntNumInputPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~KIntNumInputPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/kintnuminput.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("knuminput.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("KIntNumInput"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("Integer Input Widget (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("An input widget for integer numbers, consisting of a spinbox and a slider."); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new KIntNumInput( parent );
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class K4TimeZoneWidgetPlugin : public QObject, public QDesignerCustomWidgetInterface
{
       Q_OBJECT
       Q_INTERFACES(QDesignerCustomWidgetInterface)
public:
       K4TimeZoneWidgetPlugin(QObject *parent = nullptr) :
            QObject(parent), mInitialized(false) {}
       virtual ~K4TimeZoneWidgetPlugin() {}
       
       bool isContainer() const Q_DECL_OVERRIDE { return false; }
       bool isInitialized() const Q_DECL_OVERRIDE { return mInitialized; }
       QIcon icon() const Q_DECL_OVERRIDE { return QIcon(QStringLiteral(":/pics/k4timezonewidget.png")); }
       QString codeTemplate() const Q_DECL_OVERRIDE { return QStringLiteral(""); }
       QString domXml() const Q_DECL_OVERRIDE { return QDesignerCustomWidgetInterface::domXml(); }
       QString group() const Q_DECL_OVERRIDE { return QStringLiteral("Input (KDE - Deprecated)"); }
       QString includeFile() const Q_DECL_OVERRIDE { return QStringLiteral("k4timezonewidget.h"); }
       QString name() const Q_DECL_OVERRIDE { return QStringLiteral("K4TimeZoneWidget"); }
       QString toolTip() const Q_DECL_OVERRIDE { return QStringLiteral("This widget can be used to display or allow user selection of timezones. (KDE - Deprecated)"); }
       QString whatsThis() const Q_DECL_OVERRIDE { return QStringLiteral("K4TimeZoneWidget Widget"); }

       QWidget* createWidget( QWidget* parent ) Q_DECL_OVERRIDE 
       {
            return new K4TimeZoneWidget(parent, new KTimeZones());
       }
       void initialize(QDesignerFormEditorInterface *core) Q_DECL_OVERRIDE 
       {
            Q_UNUSED(core);
            if (mInitialized) return;
            mInitialized=true;
       }

private:
       bool mInitialized;
};


class KDELibs4SupportWidgets : public QObject, public QDesignerCustomWidgetCollectionInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetCollectionInterface)
       Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetInterface")
public:
    KDELibs4SupportWidgets(QObject *parent = nullptr);
    virtual ~KDELibs4SupportWidgets() {}
    QList<QDesignerCustomWidgetInterface*> customWidgets() const Q_DECL_OVERRIDE { return m_plugins; } 
    
private:
    QList<QDesignerCustomWidgetInterface*> m_plugins;
};

KDELibs4SupportWidgets::KDELibs4SupportWidgets(QObject *parent)
   : QObject(parent){
                m_plugins.append( new KTabBarPlugin(this) );
                m_plugins.append( new KDialogPlugin(this) );
                m_plugins.append( new KRestrictedLinePlugin(this) );
                m_plugins.append( new KDateWidgetPlugin(this) );
                m_plugins.append( new KEditListBoxPlugin(this) );
                m_plugins.append( new KTextBrowserPlugin(this) );
                m_plugins.append( new KListWidgetPlugin(this) );
                m_plugins.append( new KButtonGroupPlugin(this) );
                m_plugins.append( new KArrowButtonPlugin(this) );
                m_plugins.append( new KFontComboBoxPlugin(this) );
                m_plugins.append( new KFileMetaDataWidgetPlugin(this) );
                m_plugins.append( new KColorPatchPlugin(this) );
                m_plugins.append( new KColorValueSelectorPlugin(this) );
                m_plugins.append( new KIntSpinBoxPlugin(this) );
                m_plugins.append( new KTabWidgetPlugin(this) );
                m_plugins.append( new KPushButtonPlugin(this) );
                m_plugins.append( new KColorCellsPlugin(this) );
                m_plugins.append( new KDateTimeWidgetPlugin(this) );
                m_plugins.append( new KDialogButtonBoxPlugin(this) );
                m_plugins.append( new KDoubleNumInputPlugin(this) );
                m_plugins.append( new KIntNumInputPlugin(this) );
                m_plugins.append( new K4TimeZoneWidgetPlugin(this) );

}

#include </usr/src/ports/kf5-kdelibs4support/kf5-kdelibs4support-5.43.0-1.x86_64/build/src/kdedeprecatedwidgets.moc>

