/****************************************************************************
** Meta object code from reading C++ file 'kdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDialog_t {
    QByteArrayData data[66];
    char stringdata0[726];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDialog_t qt_meta_stringdata_KDialog = {
    {
QT_MOC_LITERAL(0, 0, 7), // "KDialog"
QT_MOC_LITERAL(1, 8, 17), // "layoutHintChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "helpClicked"
QT_MOC_LITERAL(4, 39, 14), // "defaultClicked"
QT_MOC_LITERAL(5, 54, 12), // "resetClicked"
QT_MOC_LITERAL(6, 67, 12), // "user3Clicked"
QT_MOC_LITERAL(7, 80, 12), // "user2Clicked"
QT_MOC_LITERAL(8, 93, 12), // "user1Clicked"
QT_MOC_LITERAL(9, 106, 12), // "applyClicked"
QT_MOC_LITERAL(10, 119, 10), // "tryClicked"
QT_MOC_LITERAL(11, 130, 9), // "okClicked"
QT_MOC_LITERAL(12, 140, 10), // "yesClicked"
QT_MOC_LITERAL(13, 151, 9), // "noClicked"
QT_MOC_LITERAL(14, 161, 13), // "cancelClicked"
QT_MOC_LITERAL(15, 175, 12), // "closeClicked"
QT_MOC_LITERAL(16, 188, 13), // "buttonClicked"
QT_MOC_LITERAL(17, 202, 19), // "KDialog::ButtonCode"
QT_MOC_LITERAL(18, 222, 6), // "button"
QT_MOC_LITERAL(19, 229, 6), // "hidden"
QT_MOC_LITERAL(20, 236, 8), // "finished"
QT_MOC_LITERAL(21, 245, 18), // "aboutToShowDetails"
QT_MOC_LITERAL(22, 264, 10), // "setCaption"
QT_MOC_LITERAL(23, 275, 7), // "caption"
QT_MOC_LITERAL(24, 283, 8), // "modified"
QT_MOC_LITERAL(25, 292, 15), // "setPlainCaption"
QT_MOC_LITERAL(26, 308, 12), // "enableButton"
QT_MOC_LITERAL(27, 321, 10), // "ButtonCode"
QT_MOC_LITERAL(28, 332, 2), // "id"
QT_MOC_LITERAL(29, 335, 5), // "state"
QT_MOC_LITERAL(30, 341, 14), // "enableButtonOk"
QT_MOC_LITERAL(31, 356, 17), // "enableButtonApply"
QT_MOC_LITERAL(32, 374, 18), // "enableButtonCancel"
QT_MOC_LITERAL(33, 393, 16), // "enableLinkedHelp"
QT_MOC_LITERAL(34, 410, 15), // "setHelpLinkText"
QT_MOC_LITERAL(35, 426, 4), // "text"
QT_MOC_LITERAL(36, 431, 7), // "setHelp"
QT_MOC_LITERAL(37, 439, 6), // "anchor"
QT_MOC_LITERAL(38, 446, 7), // "appname"
QT_MOC_LITERAL(39, 454, 22), // "isDetailsWidgetVisible"
QT_MOC_LITERAL(40, 477, 23), // "setDetailsWidgetVisible"
QT_MOC_LITERAL(41, 501, 7), // "visible"
QT_MOC_LITERAL(42, 509, 16), // "setDetailsWidget"
QT_MOC_LITERAL(43, 526, 8), // "QWidget*"
QT_MOC_LITERAL(44, 535, 13), // "detailsWidget"
QT_MOC_LITERAL(45, 549, 15), // "delayedDestruct"
QT_MOC_LITERAL(46, 565, 17), // "slotButtonClicked"
QT_MOC_LITERAL(47, 583, 14), // "updateGeometry"
QT_MOC_LITERAL(48, 598, 18), // "queuedLayoutUpdate"
QT_MOC_LITERAL(49, 617, 15), // "helpLinkClicked"
QT_MOC_LITERAL(50, 633, 4), // "None"
QT_MOC_LITERAL(51, 638, 4), // "Help"
QT_MOC_LITERAL(52, 643, 7), // "Default"
QT_MOC_LITERAL(53, 651, 2), // "Ok"
QT_MOC_LITERAL(54, 654, 5), // "Apply"
QT_MOC_LITERAL(55, 660, 3), // "Try"
QT_MOC_LITERAL(56, 664, 6), // "Cancel"
QT_MOC_LITERAL(57, 671, 5), // "Close"
QT_MOC_LITERAL(58, 677, 2), // "No"
QT_MOC_LITERAL(59, 680, 3), // "Yes"
QT_MOC_LITERAL(60, 684, 5), // "Reset"
QT_MOC_LITERAL(61, 690, 7), // "Details"
QT_MOC_LITERAL(62, 698, 5), // "User1"
QT_MOC_LITERAL(63, 704, 5), // "User2"
QT_MOC_LITERAL(64, 710, 5), // "User3"
QT_MOC_LITERAL(65, 716, 9) // "NoDefault"

    },
    "KDialog\0layoutHintChanged\0\0helpClicked\0"
    "defaultClicked\0resetClicked\0user3Clicked\0"
    "user2Clicked\0user1Clicked\0applyClicked\0"
    "tryClicked\0okClicked\0yesClicked\0"
    "noClicked\0cancelClicked\0closeClicked\0"
    "buttonClicked\0KDialog::ButtonCode\0"
    "button\0hidden\0finished\0aboutToShowDetails\0"
    "setCaption\0caption\0modified\0setPlainCaption\0"
    "enableButton\0ButtonCode\0id\0state\0"
    "enableButtonOk\0enableButtonApply\0"
    "enableButtonCancel\0enableLinkedHelp\0"
    "setHelpLinkText\0text\0setHelp\0anchor\0"
    "appname\0isDetailsWidgetVisible\0"
    "setDetailsWidgetVisible\0visible\0"
    "setDetailsWidget\0QWidget*\0detailsWidget\0"
    "delayedDestruct\0slotButtonClicked\0"
    "updateGeometry\0queuedLayoutUpdate\0"
    "helpLinkClicked\0None\0Help\0Default\0Ok\0"
    "Apply\0Try\0Cancel\0Close\0No\0Yes\0Reset\0"
    "Details\0User1\0User2\0User3\0NoDefault"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      37,   14, // methods
       0,    0, // properties
       1,  272, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  199,    2, 0x06 /* Public */,
       3,    0,  200,    2, 0x06 /* Public */,
       4,    0,  201,    2, 0x06 /* Public */,
       5,    0,  202,    2, 0x06 /* Public */,
       6,    0,  203,    2, 0x06 /* Public */,
       7,    0,  204,    2, 0x06 /* Public */,
       8,    0,  205,    2, 0x06 /* Public */,
       9,    0,  206,    2, 0x06 /* Public */,
      10,    0,  207,    2, 0x06 /* Public */,
      11,    0,  208,    2, 0x06 /* Public */,
      12,    0,  209,    2, 0x06 /* Public */,
      13,    0,  210,    2, 0x06 /* Public */,
      14,    0,  211,    2, 0x06 /* Public */,
      15,    0,  212,    2, 0x06 /* Public */,
      16,    1,  213,    2, 0x06 /* Public */,
      19,    0,  216,    2, 0x06 /* Public */,
      20,    0,  217,    2, 0x06 /* Public */,
      21,    0,  218,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      22,    1,  219,    2, 0x0a /* Public */,
      22,    2,  222,    2, 0x0a /* Public */,
      25,    1,  227,    2, 0x0a /* Public */,
      26,    2,  230,    2, 0x0a /* Public */,
      30,    1,  235,    2, 0x0a /* Public */,
      31,    1,  238,    2, 0x0a /* Public */,
      32,    1,  241,    2, 0x0a /* Public */,
      33,    1,  244,    2, 0x0a /* Public */,
      34,    1,  247,    2, 0x0a /* Public */,
      36,    2,  250,    2, 0x0a /* Public */,
      36,    1,  255,    2, 0x2a /* Public | MethodCloned */,
      39,    0,  258,    2, 0x0a /* Public */,
      40,    1,  259,    2, 0x0a /* Public */,
      42,    1,  262,    2, 0x0a /* Public */,
      45,    0,  265,    2, 0x0a /* Public */,
      46,    1,  266,    2, 0x09 /* Protected */,
      47,    0,  269,    2, 0x09 /* Protected */,
      48,    0,  270,    2, 0x08 /* Private */,
      49,    0,  271,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   23,   24,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, 0x80000000 | 27, QMetaType::Bool,   28,   29,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   37,   38,
    QMetaType::Void, QMetaType::QString,   37,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,   41,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // enums: name, flags, count, data
      27, 0x0,   16,  276,

 // enum data: key, value
      50, uint(KDialog::None),
      51, uint(KDialog::Help),
      52, uint(KDialog::Default),
      53, uint(KDialog::Ok),
      54, uint(KDialog::Apply),
      55, uint(KDialog::Try),
      56, uint(KDialog::Cancel),
      57, uint(KDialog::Close),
      58, uint(KDialog::No),
      59, uint(KDialog::Yes),
      60, uint(KDialog::Reset),
      61, uint(KDialog::Details),
      62, uint(KDialog::User1),
      63, uint(KDialog::User2),
      64, uint(KDialog::User3),
      65, uint(KDialog::NoDefault),

       0        // eod
};

void KDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KDialog *_t = static_cast<KDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->layoutHintChanged(); break;
        case 1: _t->helpClicked(); break;
        case 2: _t->defaultClicked(); break;
        case 3: _t->resetClicked(); break;
        case 4: _t->user3Clicked(); break;
        case 5: _t->user2Clicked(); break;
        case 6: _t->user1Clicked(); break;
        case 7: _t->applyClicked(); break;
        case 8: _t->tryClicked(); break;
        case 9: _t->okClicked(); break;
        case 10: _t->yesClicked(); break;
        case 11: _t->noClicked(); break;
        case 12: _t->cancelClicked(); break;
        case 13: _t->closeClicked(); break;
        case 14: _t->buttonClicked((*reinterpret_cast< KDialog::ButtonCode(*)>(_a[1]))); break;
        case 15: _t->hidden(); break;
        case 16: _t->finished(); break;
        case 17: _t->aboutToShowDetails(); break;
        case 18: _t->setCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->setCaption((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 20: _t->setPlainCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->enableButton((*reinterpret_cast< ButtonCode(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 22: _t->enableButtonOk((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->enableButtonApply((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->enableButtonCancel((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->enableLinkedHelp((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->setHelpLinkText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->setHelp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 28: _t->setHelp((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: { bool _r = _t->isDetailsWidgetVisible();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setDetailsWidgetVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->setDetailsWidget((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 32: _t->delayedDestruct(); break;
        case 33: _t->slotButtonClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->updateGeometry(); break;
        case 35: _t->d_ptr->queuedLayoutUpdate(); break;
        case 36: _t->d_ptr->helpLinkClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::layoutHintChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::helpClicked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::defaultClicked)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::resetClicked)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::user3Clicked)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::user2Clicked)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::user1Clicked)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::applyClicked)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::tryClicked)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::okClicked)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::yesClicked)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::noClicked)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::cancelClicked)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::closeClicked)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)(KDialog::ButtonCode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::buttonClicked)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::hidden)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::finished)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (KDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDialog::aboutToShowDetails)) {
                *result = 17;
                return;
            }
        }
    }
}

const QMetaObject KDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KDialog.data,
      qt_meta_data_KDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void KDialog::layoutHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDialog::helpClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDialog::defaultClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDialog::resetClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDialog::user3Clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDialog::user2Clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KDialog::user1Clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KDialog::applyClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KDialog::tryClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KDialog::okClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KDialog::yesClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KDialog::noClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KDialog::cancelClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KDialog::closeClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KDialog::buttonClicked(KDialog::ButtonCode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KDialog::hidden()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KDialog::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KDialog::aboutToShowDetails()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
