/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a clientadaptor -i networkstatus.h -l NetworkStatusModule /usr/src/ports/kf5-kdelibs4support/kf5-kdelibs4support-5.43.0-1.x86_64/src/kdelibs4support-5.43.0/src/solid/org.kde.Solid.Networking.Client.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "clientadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ClientAdaptor
 */

ClientAdaptor::ClientAdaptor(NetworkStatusModule *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ClientAdaptor::~ClientAdaptor()
{
    // destructor
}

uint ClientAdaptor::status() const
{
    // get the value of property Status
    return qvariant_cast< uint >(parent()->property("Status"));
}

uint ClientAdaptor::status()
{
    // handle method call org.kde.Solid.Networking.Client.status
    return parent()->status();
}


#include "clientadaptor.moc"
