/****************************************************************************
** Meta object code from reading C++ file 'kuniqueapplication_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kuniqueapplication_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kuniqueapplication_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KUniqueApplicationAdaptor_t {
    QByteArrayData data[7];
    char stringdata0[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KUniqueApplicationAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KUniqueApplicationAdaptor_t qt_meta_stringdata_KUniqueApplicationAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 25), // "KUniqueApplicationAdaptor"
QT_MOC_LITERAL(1, 26, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 42, 26), // "org.kde.KUniqueApplication"
QT_MOC_LITERAL(3, 69, 11), // "newInstance"
QT_MOC_LITERAL(4, 81, 0), // ""
QT_MOC_LITERAL(5, 82, 6), // "asn_id"
QT_MOC_LITERAL(6, 89, 4) // "args"

    },
    "KUniqueApplicationAdaptor\0D-Bus Interface\0"
    "org.kde.KUniqueApplication\0newInstance\0"
    "\0asn_id\0args"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KUniqueApplicationAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    2,   31,    4, 0x0a /* Public */,
       3,    1,   36,    4, 0x2a /* Public | MethodCloned */,
       3,    0,   39,    4, 0x2a /* Public | MethodCloned */,

 // slots: parameters
    QMetaType::Int, QMetaType::QByteArray, QMetaType::QByteArray,    5,    6,
    QMetaType::Int, QMetaType::QByteArray,    5,
    QMetaType::Int,

       0        // eod
};

void KUniqueApplicationAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KUniqueApplicationAdaptor *_t = static_cast<KUniqueApplicationAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { int _r = _t->newInstance((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->newInstance((*reinterpret_cast< const QByteArray(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->newInstance();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject KUniqueApplicationAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KUniqueApplicationAdaptor.data,
      qt_meta_data_KUniqueApplicationAdaptor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KUniqueApplicationAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUniqueApplicationAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KUniqueApplicationAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KUniqueApplicationAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
