/****************************************************************************
** Meta object code from reading C++ file 'kmenu.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kmenu.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMenu_t {
    QByteArrayData data[13];
    char stringdata0[123];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMenu_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMenu_t qt_meta_stringdata_KMenu = {
    {
QT_MOC_LITERAL(0, 0, 5), // "KMenu"
QT_MOC_LITERAL(1, 6, 22), // "aboutToShowContextMenu"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 6), // "KMenu*"
QT_MOC_LITERAL(4, 37, 4), // "menu"
QT_MOC_LITERAL(5, 42, 8), // "QAction*"
QT_MOC_LITERAL(6, 51, 10), // "menuAction"
QT_MOC_LITERAL(7, 62, 6), // "QMenu*"
QT_MOC_LITERAL(8, 69, 7), // "ctxMenu"
QT_MOC_LITERAL(9, 77, 17), // "resetKeyboardVars"
QT_MOC_LITERAL(10, 95, 1), // "b"
QT_MOC_LITERAL(11, 97, 13), // "actionHovered"
QT_MOC_LITERAL(12, 111, 11) // "showCtxMenu"

    },
    "KMenu\0aboutToShowContextMenu\0\0KMenu*\0"
    "menu\0QAction*\0menuAction\0QMenu*\0ctxMenu\0"
    "resetKeyboardVars\0b\0actionHovered\0"
    "showCtxMenu"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMenu[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   46,    2, 0x08 /* Private */,
       9,    0,   49,    2, 0x28 /* Private | MethodCloned */,
      11,    1,   50,    2, 0x08 /* Private */,
      12,    1,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 7,    4,    6,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, QMetaType::QPoint,    2,

       0        // eod
};

void KMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMenu *_t = static_cast<KMenu *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->aboutToShowContextMenu((*reinterpret_cast< KMenu*(*)>(_a[1])),(*reinterpret_cast< QAction*(*)>(_a[2])),(*reinterpret_cast< QMenu*(*)>(_a[3]))); break;
        case 1: _t->d->resetKeyboardVars((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->d->resetKeyboardVars(); break;
        case 3: _t->d->actionHovered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 4: _t->d->showCtxMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KMenu* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMenu* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KMenu::*_t)(KMenu * , QAction * , QMenu * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KMenu::aboutToShowContextMenu)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KMenu::staticMetaObject = {
    { &QMenu::staticMetaObject, qt_meta_stringdata_KMenu.data,
      qt_meta_data_KMenu,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMenu.stringdata0))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int KMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KMenu::aboutToShowContextMenu(KMenu * _t1, QAction * _t2, QMenu * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
