/****************************************************************************
** Meta object code from reading C++ file 'kcolordialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kcolordialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcolordialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KColorCells_t {
    QByteArrayData data[8];
    char stringdata0[78];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KColorCells_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KColorCells_t qt_meta_stringdata_KColorCells = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KColorCells"
QT_MOC_LITERAL(1, 12, 13), // "colorSelected"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 5), // "index"
QT_MOC_LITERAL(4, 33, 5), // "color"
QT_MOC_LITERAL(5, 39, 18), // "colorDoubleClicked"
QT_MOC_LITERAL(6, 58, 11), // "acceptDrags"
QT_MOC_LITERAL(7, 70, 7) // "shading"

    },
    "KColorCells\0colorSelected\0\0index\0color\0"
    "colorDoubleClicked\0acceptDrags\0shading"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KColorCells[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       2,   34, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,
       5,    2,   29,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    3,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    3,    4,

 // properties: name, type, flags
       6, QMetaType::Bool, 0x00095103,
       7, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KColorCells::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KColorCells *_t = static_cast<KColorCells *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorSelected((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 1: _t->colorDoubleClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KColorCells::*_t)(int , const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorCells::colorSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KColorCells::*_t)(int , const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorCells::colorDoubleClicked)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KColorCells *_t = static_cast<KColorCells *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->acceptDrags(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->shading(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KColorCells *_t = static_cast<KColorCells *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAcceptDrags(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setShading(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KColorCells::staticMetaObject = {
    { &QTableWidget::staticMetaObject, qt_meta_stringdata_KColorCells.data,
      qt_meta_data_KColorCells,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KColorCells::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KColorCells::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KColorCells.stringdata0))
        return static_cast<void*>(this);
    return QTableWidget::qt_metacast(_clname);
}

int KColorCells::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTableWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KColorCells::colorSelected(int _t1, const QColor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KColorCells::colorDoubleClicked(int _t1, const QColor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KColorPatch_t {
    QByteArrayData data[4];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KColorPatch_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KColorPatch_t qt_meta_stringdata_KColorPatch = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KColorPatch"
QT_MOC_LITERAL(1, 12, 12), // "colorChanged"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 5) // "color"

    },
    "KColorPatch\0colorChanged\0\0color"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KColorPatch[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       1,   22, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor,    2,

 // properties: name, type, flags
       3, QMetaType::QColor, 0x00095103,

       0        // eod
};

void KColorPatch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KColorPatch *_t = static_cast<KColorPatch *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KColorPatch::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorPatch::colorChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KColorPatch *_t = static_cast<KColorPatch *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KColorPatch *_t = static_cast<KColorPatch *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KColorPatch::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_KColorPatch.data,
      qt_meta_data_KColorPatch,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KColorPatch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KColorPatch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KColorPatch.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int KColorPatch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KColorPatch::colorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KColorDialog_t {
    QByteArrayData data[24];
    char stringdata0[330];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KColorDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KColorDialog_t qt_meta_stringdata_KColorDialog = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KColorDialog"
QT_MOC_LITERAL(1, 13, 13), // "colorSelected"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 3), // "col"
QT_MOC_LITERAL(4, 32, 8), // "setColor"
QT_MOC_LITERAL(5, 41, 14), // "slotRGBChanged"
QT_MOC_LITERAL(6, 56, 16), // "slotAlphaChanged"
QT_MOC_LITERAL(7, 73, 14), // "slotHSVChanged"
QT_MOC_LITERAL(8, 88, 15), // "slotHtmlChanged"
QT_MOC_LITERAL(9, 104, 13), // "slotHSChanged"
QT_MOC_LITERAL(10, 118, 12), // "slotVChanged"
QT_MOC_LITERAL(11, 131, 12), // "slotAChanged"
QT_MOC_LITERAL(12, 144, 17), // "slotColorSelected"
QT_MOC_LITERAL(13, 162, 4), // "name"
QT_MOC_LITERAL(14, 167, 22), // "slotColorDoubleClicked"
QT_MOC_LITERAL(15, 190, 15), // "slotColorPicker"
QT_MOC_LITERAL(16, 206, 21), // "slotAddToCustomColors"
QT_MOC_LITERAL(17, 228, 23), // "slotDefaultColorClicked"
QT_MOC_LITERAL(18, 252, 15), // "slotModeChanged"
QT_MOC_LITERAL(19, 268, 2), // "id"
QT_MOC_LITERAL(20, 271, 17), // "slotWriteSettings"
QT_MOC_LITERAL(21, 289, 21), // "isAlphaChannelEnabled"
QT_MOC_LITERAL(22, 311, 12), // "defaultColor"
QT_MOC_LITERAL(23, 324, 5) // "color"

    },
    "KColorDialog\0colorSelected\0\0col\0"
    "setColor\0slotRGBChanged\0slotAlphaChanged\0"
    "slotHSVChanged\0slotHtmlChanged\0"
    "slotHSChanged\0slotVChanged\0slotAChanged\0"
    "slotColorSelected\0name\0slotColorDoubleClicked\0"
    "slotColorPicker\0slotAddToCustomColors\0"
    "slotDefaultColorClicked\0slotModeChanged\0"
    "id\0slotWriteSettings\0isAlphaChannelEnabled\0"
    "defaultColor\0color"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KColorDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       3,  140, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,  102,    2, 0x0a /* Public */,
       5,    0,  105,    2, 0x08 /* Private */,
       6,    0,  106,    2, 0x08 /* Private */,
       7,    0,  107,    2, 0x08 /* Private */,
       8,    0,  108,    2, 0x08 /* Private */,
       9,    2,  109,    2, 0x08 /* Private */,
      10,    1,  114,    2, 0x08 /* Private */,
      11,    1,  117,    2, 0x08 /* Private */,
      12,    1,  120,    2, 0x08 /* Private */,
      12,    2,  123,    2, 0x08 /* Private */,
      14,    2,  128,    2, 0x08 /* Private */,
      15,    0,  133,    2, 0x08 /* Private */,
      16,    0,  134,    2, 0x08 /* Private */,
      17,    0,  135,    2, 0x08 /* Private */,
      18,    1,  136,    2, 0x08 /* Private */,
      20,    0,  139,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QColor,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QColor,    3,
    QMetaType::Void, QMetaType::QColor, QMetaType::QString,    3,   13,
    QMetaType::Void, QMetaType::QColor, QMetaType::QString,    3,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void,

 // properties: name, type, flags
      21, QMetaType::Bool, 0x00095003,
      22, QMetaType::QColor, 0x00095103,
      23, QMetaType::QColor, 0x00095103,

       0        // eod
};

void KColorDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KColorDialog *_t = static_cast<KColorDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorSelected((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 1: _t->setColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 2: _t->d->slotRGBChanged(); break;
        case 3: _t->d->slotAlphaChanged(); break;
        case 4: _t->d->slotHSVChanged(); break;
        case 5: _t->d->slotHtmlChanged(); break;
        case 6: _t->d->slotHSChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->d->slotVChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->d->slotAChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->d->slotColorSelected((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 10: _t->d->slotColorSelected((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->d->slotColorDoubleClicked((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->d->slotColorPicker(); break;
        case 13: _t->d->slotAddToCustomColors(); break;
        case 14: _t->d->slotDefaultColorClicked(); break;
        case 15: _t->d->slotModeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->d->slotWriteSettings(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KColorDialog::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorDialog::colorSelected)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KColorDialog *_t = static_cast<KColorDialog *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isAlphaChannelEnabled(); break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->defaultColor(); break;
        case 2: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KColorDialog *_t = static_cast<KColorDialog *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAlphaChannelEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setDefaultColor(*reinterpret_cast< QColor*>(_v)); break;
        case 2: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KColorDialog::staticMetaObject = {
    { &KDialog::staticMetaObject, qt_meta_stringdata_KColorDialog.data,
      qt_meta_data_KColorDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KColorDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KColorDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KColorDialog.stringdata0))
        return static_cast<void*>(this);
    return KDialog::qt_metacast(_clname);
}

int KColorDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KColorDialog::colorSelected(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
