/****************************************************************************
** Meta object code from reading C++ file 'networkstatus.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/kdelibs4support-5.43.0/src/solid-networkstatus/kded/networkstatus.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkstatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NetworkStatusModule_t {
    QByteArrayData data[19];
    char stringdata0[306];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkStatusModule_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkStatusModule_t qt_meta_stringdata_NetworkStatusModule = {
    {
QT_MOC_LITERAL(0, 0, 19), // "NetworkStatusModule"
QT_MOC_LITERAL(1, 20, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 36, 24), // "org.kde.Solid.Networking"
QT_MOC_LITERAL(3, 61, 13), // "statusChanged"
QT_MOC_LITERAL(4, 75, 0), // ""
QT_MOC_LITERAL(5, 76, 6), // "status"
QT_MOC_LITERAL(6, 83, 8), // "networks"
QT_MOC_LITERAL(7, 92, 16), // "setNetworkStatus"
QT_MOC_LITERAL(8, 109, 11), // "networkName"
QT_MOC_LITERAL(9, 121, 15), // "registerNetwork"
QT_MOC_LITERAL(10, 137, 11), // "serviceName"
QT_MOC_LITERAL(11, 149, 17), // "unregisterNetwork"
QT_MOC_LITERAL(12, 167, 19), // "serviceUnregistered"
QT_MOC_LITERAL(13, 187, 4), // "name"
QT_MOC_LITERAL(14, 192, 28), // "solidNetworkingStatusChanged"
QT_MOC_LITERAL(15, 221, 25), // "Solid::Networking::Status"
QT_MOC_LITERAL(16, 247, 17), // "backendRegistered"
QT_MOC_LITERAL(17, 265, 19), // "backendUnregistered"
QT_MOC_LITERAL(18, 285, 20) // "delayedStatusChanged"

    },
    "NetworkStatusModule\0D-Bus Interface\0"
    "org.kde.Solid.Networking\0statusChanged\0"
    "\0status\0networks\0setNetworkStatus\0"
    "networkName\0registerNetwork\0serviceName\0"
    "unregisterNetwork\0serviceUnregistered\0"
    "name\0solidNetworkingStatusChanged\0"
    "Solid::Networking::Status\0backendRegistered\0"
    "backendUnregistered\0delayedStatusChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkStatusModule[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      11,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   71,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   74,    4, 0x4a /* Public | isScriptable */,
       6,    0,   75,    4, 0x4a /* Public | isScriptable */,
       7,    2,   76,    4, 0x4a /* Public | isScriptable */,
       9,    3,   81,    4, 0x4a /* Public | isScriptable */,
      11,    1,   88,    4, 0x4a /* Public | isScriptable */,
      12,    1,   91,    4, 0x09 /* Protected */,
      14,    1,   94,    4, 0x09 /* Protected */,
      16,    0,   97,    4, 0x09 /* Protected */,
      17,    0,   98,    4, 0x09 /* Protected */,
      18,    0,   99,    4, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::UInt,    5,

 // slots: parameters
    QMetaType::Int,
    QMetaType::QStringList,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    8,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    8,    5,   10,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, 0x80000000 | 15,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void NetworkStatusModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NetworkStatusModule *_t = static_cast<NetworkStatusModule *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 1: { int _r = _t->status();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 2: { QStringList _r = _t->networks();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setNetworkStatus((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->registerNetwork((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 5: _t->unregisterNetwork((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->serviceUnregistered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->solidNetworkingStatusChanged((*reinterpret_cast< Solid::Networking::Status(*)>(_a[1]))); break;
        case 8: _t->backendRegistered(); break;
        case 9: _t->backendUnregistered(); break;
        case 10: _t->delayedStatusChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NetworkStatusModule::*_t)(uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkStatusModule::statusChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject NetworkStatusModule::staticMetaObject = {
    { &KDEDModule::staticMetaObject, qt_meta_stringdata_NetworkStatusModule.data,
      qt_meta_data_NetworkStatusModule,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *NetworkStatusModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkStatusModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkStatusModule.stringdata0))
        return static_cast<void*>(this);
    return KDEDModule::qt_metacast(_clname);
}

int NetworkStatusModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDEDModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void NetworkStatusModule::statusChanged(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
