#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'cacertificates.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CACERTIFICATES_H
#define UI_CACERTIFICATES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CaCertificatesPage
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *treeWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *displaySelection;
    QSpacerItem *horizontalSpacer;
    QPushButton *disableSelection;
    QPushButton *enableSelection;
    QSpacerItem *spacer;
    QPushButton *removeSelection;
    QPushButton *add;

    void setupUi(QWidget *CaCertificatesPage)
    {
        if (CaCertificatesPage->objectName().isEmpty())
            CaCertificatesPage->setObjectName(QStringLiteral("CaCertificatesPage"));
        CaCertificatesPage->resize(586, 562);
        verticalLayout = new QVBoxLayout(CaCertificatesPage);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        treeWidget = new QTreeWidget(CaCertificatesPage);
        treeWidget->setObjectName(QStringLiteral("treeWidget"));
        treeWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeWidget->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(treeWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        displaySelection = new QPushButton(CaCertificatesPage);
        displaySelection->setObjectName(QStringLiteral("displaySelection"));
        displaySelection->setEnabled(false);

        horizontalLayout->addWidget(displaySelection);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        disableSelection = new QPushButton(CaCertificatesPage);
        disableSelection->setObjectName(QStringLiteral("disableSelection"));
        disableSelection->setEnabled(false);

        horizontalLayout->addWidget(disableSelection);

        enableSelection = new QPushButton(CaCertificatesPage);
        enableSelection->setObjectName(QStringLiteral("enableSelection"));
        enableSelection->setEnabled(false);

        horizontalLayout->addWidget(enableSelection);

        spacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacer);

        removeSelection = new QPushButton(CaCertificatesPage);
        removeSelection->setObjectName(QStringLiteral("removeSelection"));
        removeSelection->setEnabled(false);

        horizontalLayout->addWidget(removeSelection);

        add = new QPushButton(CaCertificatesPage);
        add->setObjectName(QStringLiteral("add"));

        horizontalLayout->addWidget(add);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(CaCertificatesPage);

        QMetaObject::connectSlotsByName(CaCertificatesPage);
    } // setupUi

    void retranslateUi(QWidget *CaCertificatesPage)
    {
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Organizational Unit", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, tr2i18n("Organization / Common Name", Q_NULLPTR));
        displaySelection->setText(tr2i18n("Display...", Q_NULLPTR));
        disableSelection->setText(tr2i18n("Disable", Q_NULLPTR));
        enableSelection->setText(tr2i18n("Enable", Q_NULLPTR));
        removeSelection->setText(tr2i18n("Remove", Q_NULLPTR));
        add->setText(tr2i18n("Add...", Q_NULLPTR));
        Q_UNUSED(CaCertificatesPage);
    } // retranslateUi

};

namespace Ui {
    class CaCertificatesPage: public Ui_CaCertificatesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CACERTIFICATES_H

