/****************************************************************************
** Meta object code from reading C++ file 'kfiletreeview_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kio/kfiletreeview_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kfiletreeview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KFileTreeView_t {
    QByteArrayData data[13];
    char stringdata0[154];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KFileTreeView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KFileTreeView_t qt_meta_stringdata_KFileTreeView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KFileTreeView"
QT_MOC_LITERAL(1, 14, 9), // "activated"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 3), // "url"
QT_MOC_LITERAL(4, 29, 14), // "currentChanged"
QT_MOC_LITERAL(5, 44, 14), // "setDirOnlyMode"
QT_MOC_LITERAL(6, 59, 7), // "enabled"
QT_MOC_LITERAL(7, 67, 18), // "setShowHiddenFiles"
QT_MOC_LITERAL(8, 86, 13), // "setCurrentUrl"
QT_MOC_LITERAL(9, 100, 10), // "setRootUrl"
QT_MOC_LITERAL(10, 111, 12), // "_k_activated"
QT_MOC_LITERAL(11, 124, 17), // "_k_currentChanged"
QT_MOC_LITERAL(12, 142, 11) // "_k_expanded"

    },
    "KFileTreeView\0activated\0\0url\0"
    "currentChanged\0setDirOnlyMode\0enabled\0"
    "setShowHiddenFiles\0setCurrentUrl\0"
    "setRootUrl\0_k_activated\0_k_currentChanged\0"
    "_k_expanded"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KFileTreeView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       4,    1,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   65,    2, 0x0a /* Public */,
       7,    1,   68,    2, 0x0a /* Public */,
       8,    1,   71,    2, 0x0a /* Public */,
       9,    1,   74,    2, 0x0a /* Public */,
      10,    1,   77,    2, 0x08 /* Private */,
      11,    2,   80,    2, 0x08 /* Private */,
      12,    1,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, QMetaType::QUrl,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,

       0        // eod
};

void KFileTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KFileTreeView *_t = static_cast<KFileTreeView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->activated((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->currentChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 2: _t->setDirOnlyMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setShowHiddenFiles((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->setCurrentUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 5: _t->setRootUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->d->_k_activated((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->d->_k_currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 8: _t->d->_k_expanded((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KFileTreeView::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KFileTreeView::activated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KFileTreeView::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KFileTreeView::currentChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KFileTreeView::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_KFileTreeView.data,
      qt_meta_data_KFileTreeView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KFileTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KFileTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KFileTreeView.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int KFileTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KFileTreeView::activated(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KFileTreeView::currentChanged(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
