/****************************************************************************
** Meta object code from reading C++ file 'kaction.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kaction.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KAction_t {
    QByteArrayData data[23];
    char stringdata0[331];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KAction_t qt_meta_stringdata_KAction = {
    {
QT_MOC_LITERAL(0, 0, 7), // "KAction"
QT_MOC_LITERAL(1, 8, 9), // "triggered"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(4, 36, 7), // "buttons"
QT_MOC_LITERAL(5, 44, 21), // "Qt::KeyboardModifiers"
QT_MOC_LITERAL(6, 66, 9), // "modifiers"
QT_MOC_LITERAL(7, 76, 10), // "authorized"
QT_MOC_LITERAL(8, 87, 13), // "KAuth::Action"
QT_MOC_LITERAL(9, 101, 6), // "action"
QT_MOC_LITERAL(10, 108, 21), // "globalShortcutChanged"
QT_MOC_LITERAL(11, 130, 13), // "slotTriggered"
QT_MOC_LITERAL(12, 144, 34), // "_k_emitActionGlobalShortcutCh..."
QT_MOC_LITERAL(13, 179, 8), // "QAction*"
QT_MOC_LITERAL(14, 188, 8), // "shortcut"
QT_MOC_LITERAL(15, 197, 9), // "KShortcut"
QT_MOC_LITERAL(16, 207, 20), // "shortcutConfigurable"
QT_MOC_LITERAL(17, 228, 14), // "globalShortcut"
QT_MOC_LITERAL(18, 243, 21), // "globalShortcutAllowed"
QT_MOC_LITERAL(19, 265, 21), // "globalShortcutEnabled"
QT_MOC_LITERAL(20, 287, 12), // "ShortcutType"
QT_MOC_LITERAL(21, 300, 14), // "ActiveShortcut"
QT_MOC_LITERAL(22, 315, 15) // "DefaultShortcut"

    },
    "KAction\0triggered\0\0Qt::MouseButtons\0"
    "buttons\0Qt::KeyboardModifiers\0modifiers\0"
    "authorized\0KAuth::Action\0action\0"
    "globalShortcutChanged\0slotTriggered\0"
    "_k_emitActionGlobalShortcutChanged\0"
    "QAction*\0shortcut\0KShortcut\0"
    "shortcutConfigurable\0globalShortcut\0"
    "globalShortcutAllowed\0globalShortcutEnabled\0"
    "ShortcutType\0ActiveShortcut\0DefaultShortcut"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KAction[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       5,   56, // properties
       1,   71, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,
       7,    1,   44,    2, 0x06 /* Public */,
      10,    1,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   50,    2, 0x08 /* Private */,
      12,    2,   51,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::QKeySequence,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QKeySequence,    2,    2,

 // properties: name, type, flags
      14, 0x80000000 | 15, 0x0009510b,
      16, QMetaType::Bool, 0x00095103,
      17, 0x80000000 | 15, 0x0009510b,
      18, QMetaType::Bool, 0x00095103,
      19, QMetaType::Bool, 0x00095001,

 // enums: name, flags, count, data
      20, 0x1,    2,   75,

 // enum data: key, value
      21, uint(KAction::ActiveShortcut),
      22, uint(KAction::DefaultShortcut),

       0        // eod
};

void KAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KAction *_t = static_cast<KAction *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->triggered((*reinterpret_cast< Qt::MouseButtons(*)>(_a[1])),(*reinterpret_cast< Qt::KeyboardModifiers(*)>(_a[2]))); break;
        case 1: _t->authorized((*reinterpret_cast< const KAuth::Action(*)>(_a[1]))); break;
        case 2: _t->globalShortcutChanged((*reinterpret_cast< const QKeySequence(*)>(_a[1]))); break;
        case 3: _t->d->slotTriggered(); break;
        case 4: _t->d->_k_emitActionGlobalShortcutChanged((*reinterpret_cast< QAction*(*)>(_a[1])),(*reinterpret_cast< const QKeySequence(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KAction::*_t)(Qt::MouseButtons , Qt::KeyboardModifiers );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAction::triggered)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KAction::*_t)(const KAuth::Action & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAction::authorized)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KAction::*_t)(const QKeySequence & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAction::globalShortcutChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KAction *_t = static_cast<KAction *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< KShortcut*>(_v) = _t->shortcut(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isShortcutConfigurable(); break;
        case 2: *reinterpret_cast< KShortcut*>(_v) = _t->globalShortcut(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->globalShortcutAllowed(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isGlobalShortcutEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KAction *_t = static_cast<KAction *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShortcut(*reinterpret_cast< KShortcut*>(_v)); break;
        case 1: _t->setShortcutConfigurable(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setGlobalShortcut(*reinterpret_cast< KShortcut*>(_v)); break;
        case 3: _t->setGlobalShortcutAllowed(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KAction::staticMetaObject = {
    { &QWidgetAction::staticMetaObject, qt_meta_stringdata_KAction.data,
      qt_meta_data_KAction,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KAction.stringdata0))
        return static_cast<void*>(this);
    return QWidgetAction::qt_metacast(_clname);
}

int KAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidgetAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KAction::triggered(Qt::MouseButtons _t1, Qt::KeyboardModifiers _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KAction::authorized(const KAuth::Action & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KAction::globalShortcutChanged(const QKeySequence & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
