/****************************************************************************
** Meta object code from reading C++ file 'ktabbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/ktabbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTabBar_t {
    QByteArrayData data[22];
    char stringdata0[299];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTabBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTabBar_t qt_meta_stringdata_KTabBar = {
    {
QT_MOC_LITERAL(0, 0, 7), // "KTabBar"
QT_MOC_LITERAL(1, 8, 11), // "contextMenu"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 5), // "index"
QT_MOC_LITERAL(4, 27, 9), // "globalPos"
QT_MOC_LITERAL(5, 37, 20), // "emptyAreaContextMenu"
QT_MOC_LITERAL(6, 58, 16), // "mouseDoubleClick"
QT_MOC_LITERAL(7, 75, 16), // "tabDoubleClicked"
QT_MOC_LITERAL(8, 92, 13), // "newTabRequest"
QT_MOC_LITERAL(9, 106, 16), // "mouseMiddleClick"
QT_MOC_LITERAL(10, 123, 12), // "initiateDrag"
QT_MOC_LITERAL(11, 136, 13), // "testCanDecode"
QT_MOC_LITERAL(12, 150, 21), // "const QDragMoveEvent*"
QT_MOC_LITERAL(13, 172, 5), // "bool&"
QT_MOC_LITERAL(14, 178, 17), // "receivedDropEvent"
QT_MOC_LITERAL(15, 196, 11), // "QDropEvent*"
QT_MOC_LITERAL(16, 208, 7), // "moveTab"
QT_MOC_LITERAL(17, 216, 12), // "closeRequest"
QT_MOC_LITERAL(18, 229, 10), // "wheelDelta"
QT_MOC_LITERAL(19, 240, 18), // "closeButtonClicked"
QT_MOC_LITERAL(20, 259, 17), // "enableCloseButton"
QT_MOC_LITERAL(21, 277, 21) // "activateDragSwitchTab"

    },
    "KTabBar\0contextMenu\0\0index\0globalPos\0"
    "emptyAreaContextMenu\0mouseDoubleClick\0"
    "tabDoubleClicked\0newTabRequest\0"
    "mouseMiddleClick\0initiateDrag\0"
    "testCanDecode\0const QDragMoveEvent*\0"
    "bool&\0receivedDropEvent\0QDropEvent*\0"
    "moveTab\0closeRequest\0wheelDelta\0"
    "closeButtonClicked\0enableCloseButton\0"
    "activateDragSwitchTab"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTabBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x06 /* Public */,
       5,    1,   94,    2, 0x06 /* Public */,
       6,    1,   97,    2, 0x16 /* Public | MethodCompatibility */,
       7,    1,  100,    2, 0x06 /* Public */,
       8,    0,  103,    2, 0x06 /* Public */,
       9,    1,  104,    2, 0x06 /* Public */,
      10,    1,  107,    2, 0x06 /* Public */,
      11,    2,  110,    2, 0x06 /* Public */,
      14,    2,  115,    2, 0x06 /* Public */,
      16,    2,  120,    2, 0x06 /* Public */,
      17,    1,  125,    2, 0x16 /* Public | MethodCompatibility */,
      18,    1,  128,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  131,    2, 0x19 /* Protected | MethodCompatibility */,
      20,    0,  132,    2, 0x19 /* Protected | MethodCompatibility */,
      21,    0,  133,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint,    3,    4,
    QMetaType::Void, QMetaType::QPoint,    4,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 13,    2,    2,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 15,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KTabBar *_t = static_cast<KTabBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->contextMenu((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 1: _t->emptyAreaContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 2: _t->mouseDoubleClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->tabDoubleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->newTabRequest(); break;
        case 5: _t->mouseMiddleClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->initiateDrag((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->testCanDecode((*reinterpret_cast< const QDragMoveEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->receivedDropEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QDropEvent*(*)>(_a[2]))); break;
        case 9: _t->moveTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->closeRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->wheelDelta((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->closeButtonClicked(); break;
        case 13: _t->enableCloseButton(); break;
        case 14: _t->activateDragSwitchTab(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KTabBar::*_t)(int , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::contextMenu)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::emptyAreaContextMenu)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::mouseDoubleClick)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::tabDoubleClicked)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::newTabRequest)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::mouseMiddleClick)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::initiateDrag)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(const QDragMoveEvent * , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::testCanDecode)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int , QDropEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::receivedDropEvent)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::moveTab)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::closeRequest)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KTabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabBar::wheelDelta)) {
                *result = 11;
                return;
            }
        }
    }
}

const QMetaObject KTabBar::staticMetaObject = {
    { &QTabBar::staticMetaObject, qt_meta_stringdata_KTabBar.data,
      qt_meta_data_KTabBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTabBar.stringdata0))
        return static_cast<void*>(this);
    return QTabBar::qt_metacast(_clname);
}

int KTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KTabBar::contextMenu(int _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTabBar::emptyAreaContextMenu(const QPoint & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTabBar::mouseDoubleClick(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTabBar::tabDoubleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTabBar::newTabRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KTabBar::mouseMiddleClick(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KTabBar::initiateDrag(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTabBar::testCanDecode(const QDragMoveEvent * _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KTabBar::receivedDropEvent(int _t1, QDropEvent * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KTabBar::moveTab(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KTabBar::closeRequest(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KTabBar::wheelDelta(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
