/****************************************************************************
** Meta object code from reading C++ file 'ktabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/ktabwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KTabWidget_t {
    QByteArrayData data[38];
    char stringdata0[538];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KTabWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KTabWidget_t qt_meta_stringdata_KTabWidget = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KTabWidget"
QT_MOC_LITERAL(1, 11, 13), // "testCanDecode"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 21), // "const QDragMoveEvent*"
QT_MOC_LITERAL(4, 48, 1), // "e"
QT_MOC_LITERAL(5, 50, 5), // "bool&"
QT_MOC_LITERAL(6, 56, 6), // "accept"
QT_MOC_LITERAL(7, 63, 17), // "receivedDropEvent"
QT_MOC_LITERAL(8, 81, 11), // "QDropEvent*"
QT_MOC_LITERAL(9, 93, 8), // "QWidget*"
QT_MOC_LITERAL(10, 102, 12), // "initiateDrag"
QT_MOC_LITERAL(11, 115, 11), // "contextMenu"
QT_MOC_LITERAL(12, 127, 8), // "movedTab"
QT_MOC_LITERAL(13, 136, 16), // "mouseDoubleClick"
QT_MOC_LITERAL(14, 153, 16), // "mouseMiddleClick"
QT_MOC_LITERAL(15, 170, 12), // "closeRequest"
QT_MOC_LITERAL(16, 183, 7), // "moveTab"
QT_MOC_LITERAL(17, 191, 10), // "removePage"
QT_MOC_LITERAL(18, 202, 1), // "w"
QT_MOC_LITERAL(19, 204, 9), // "removeTab"
QT_MOC_LITERAL(20, 214, 5), // "index"
QT_MOC_LITERAL(21, 220, 23), // "setTabReorderingEnabled"
QT_MOC_LITERAL(22, 244, 6), // "enable"
QT_MOC_LITERAL(23, 251, 19), // "setHoverCloseButton"
QT_MOC_LITERAL(24, 271, 26), // "setHoverCloseButtonDelayed"
QT_MOC_LITERAL(25, 298, 7), // "delayed"
QT_MOC_LITERAL(26, 306, 21), // "setCloseButtonEnabled"
QT_MOC_LITERAL(27, 328, 27), // "setTabCloseActivatePrevious"
QT_MOC_LITERAL(28, 356, 8), // "previous"
QT_MOC_LITERAL(29, 365, 22), // "setAutomaticResizeTabs"
QT_MOC_LITERAL(30, 388, 10), // "wheelDelta"
QT_MOC_LITERAL(31, 399, 12), // "slotTabMoved"
QT_MOC_LITERAL(32, 412, 20), // "tabReorderingEnabled"
QT_MOC_LITERAL(33, 433, 16), // "hoverCloseButton"
QT_MOC_LITERAL(34, 450, 23), // "hoverCloseButtonDelayed"
QT_MOC_LITERAL(35, 474, 18), // "closeButtonEnabled"
QT_MOC_LITERAL(36, 493, 24), // "tabCloseActivatePrevious"
QT_MOC_LITERAL(37, 518, 19) // "automaticResizeTabs"

    },
    "KTabWidget\0testCanDecode\0\0"
    "const QDragMoveEvent*\0e\0bool&\0accept\0"
    "receivedDropEvent\0QDropEvent*\0QWidget*\0"
    "initiateDrag\0contextMenu\0movedTab\0"
    "mouseDoubleClick\0mouseMiddleClick\0"
    "closeRequest\0moveTab\0removePage\0w\0"
    "removeTab\0index\0setTabReorderingEnabled\0"
    "enable\0setHoverCloseButton\0"
    "setHoverCloseButtonDelayed\0delayed\0"
    "setCloseButtonEnabled\0setTabCloseActivatePrevious\0"
    "previous\0setAutomaticResizeTabs\0"
    "wheelDelta\0slotTabMoved\0tabReorderingEnabled\0"
    "hoverCloseButton\0hoverCloseButtonDelayed\0"
    "closeButtonEnabled\0tabCloseActivatePrevious\0"
    "automaticResizeTabs"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KTabWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       6,  258, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  159,    2, 0x06 /* Public */,
       7,    1,  164,    2, 0x06 /* Public */,
       7,    2,  167,    2, 0x06 /* Public */,
      10,    1,  172,    2, 0x06 /* Public */,
      11,    1,  175,    2, 0x06 /* Public */,
      11,    2,  178,    2, 0x06 /* Public */,
      12,    2,  183,    2, 0x06 /* Public */,
      13,    0,  188,    2, 0x06 /* Public */,
      13,    1,  189,    2, 0x06 /* Public */,
      14,    0,  192,    2, 0x06 /* Public */,
      14,    1,  193,    2, 0x06 /* Public */,
      15,    1,  196,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    2,  199,    2, 0x0a /* Public */,
      17,    1,  204,    2, 0x1a /* Public | MethodCompatibility */,
      19,    1,  207,    2, 0x0a /* Public */,
      21,    1,  210,    2, 0x1a /* Public | MethodCompatibility */,
      23,    1,  213,    2, 0x1a /* Public | MethodCompatibility */,
      24,    1,  216,    2, 0x1a /* Public | MethodCompatibility */,
      26,    1,  219,    2, 0x1a /* Public | MethodCompatibility */,
      27,    1,  222,    2, 0x1a /* Public | MethodCompatibility */,
      29,    1,  225,    2, 0x0a /* Public */,
       7,    2,  228,    2, 0x09 /* Protected */,
      10,    1,  233,    2, 0x09 /* Protected */,
      11,    2,  236,    2, 0x09 /* Protected */,
      13,    1,  241,    2, 0x09 /* Protected */,
      14,    1,  244,    2, 0x09 /* Protected */,
      15,    1,  247,    2, 0x09 /* Protected */,
      30,    1,  250,    2, 0x09 /* Protected */,
      31,    2,  253,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 8,    2,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QPoint,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 9,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, 0x80000000 | 9,   18,
    QMetaType::Void, QMetaType::Int,   20,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 8,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QPoint,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,

 // properties: name, type, flags
      32, QMetaType::Bool, 0x00095103,
      33, QMetaType::Bool, 0x00095103,
      34, QMetaType::Bool, 0x00095103,
      35, QMetaType::Bool, 0x00095103,
      36, QMetaType::Bool, 0x00095103,
      37, QMetaType::Bool, 0x00095103,

       0        // eod
};

void KTabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KTabWidget *_t = static_cast<KTabWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->testCanDecode((*reinterpret_cast< const QDragMoveEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->receivedDropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 2: _t->receivedDropEvent((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QDropEvent*(*)>(_a[2]))); break;
        case 3: _t->initiateDrag((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 4: _t->contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 5: _t->contextMenu((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 6: _t->movedTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->mouseDoubleClick(); break;
        case 8: _t->mouseDoubleClick((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 9: _t->mouseMiddleClick(); break;
        case 10: _t->mouseMiddleClick((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 11: _t->closeRequest((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 12: _t->moveTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->removePage((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 14: _t->removeTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->setTabReorderingEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->setHoverCloseButton((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setHoverCloseButtonDelayed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->setCloseButtonEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->setTabCloseActivatePrevious((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->setAutomaticResizeTabs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->receivedDropEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QDropEvent*(*)>(_a[2]))); break;
        case 22: _t->initiateDrag((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->contextMenu((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 24: _t->mouseDoubleClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->mouseMiddleClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->closeRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->wheelDelta((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 28: _t->d->slotTabMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KTabWidget::*_t)(const QDragMoveEvent * , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::testCanDecode)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QDropEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::receivedDropEvent)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * , QDropEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::receivedDropEvent)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::initiateDrag)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::contextMenu)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::contextMenu)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::movedTab)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::mouseDoubleClick)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::mouseDoubleClick)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::mouseMiddleClick)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::mouseMiddleClick)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (KTabWidget::*_t)(QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KTabWidget::closeRequest)) {
                *result = 11;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KTabWidget *_t = static_cast<KTabWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isTabReorderingEnabled(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->hoverCloseButton(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->hoverCloseButtonDelayed(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isCloseButtonEnabled(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->tabCloseActivatePrevious(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->automaticResizeTabs(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KTabWidget *_t = static_cast<KTabWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTabReorderingEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setHoverCloseButton(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setHoverCloseButtonDelayed(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setCloseButtonEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setTabCloseActivatePrevious(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setAutomaticResizeTabs(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KTabWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_KTabWidget.data,
      qt_meta_data_KTabWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KTabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KTabWidget.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int KTabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KTabWidget::testCanDecode(const QDragMoveEvent * _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KTabWidget::receivedDropEvent(QDropEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KTabWidget::receivedDropEvent(QWidget * _t1, QDropEvent * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KTabWidget::initiateDrag(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KTabWidget::contextMenu(const QPoint & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KTabWidget::contextMenu(QWidget * _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KTabWidget::movedTab(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KTabWidget::mouseDoubleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KTabWidget::mouseDoubleClick(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KTabWidget::mouseMiddleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KTabWidget::mouseMiddleClick(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KTabWidget::closeRequest(QWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
