/****************************************************************************
** Meta object code from reading C++ file 'k3clientsocketbase.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdecore/k3clientsocketbase.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3clientsocketbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNetwork__KClientSocketBase_t {
    QByteArrayData data[20];
    char stringdata0[227];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNetwork__KClientSocketBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNetwork__KClientSocketBase_t qt_meta_stringdata_KNetwork__KClientSocketBase = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KNetwork::KClientSocketBase"
QT_MOC_LITERAL(1, 28, 12), // "stateChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 8), // "newstate"
QT_MOC_LITERAL(4, 51, 8), // "gotError"
QT_MOC_LITERAL(5, 60, 4), // "code"
QT_MOC_LITERAL(6, 65, 9), // "hostFound"
QT_MOC_LITERAL(7, 75, 5), // "bound"
QT_MOC_LITERAL(8, 81, 24), // "KNetwork::KResolverEntry"
QT_MOC_LITERAL(9, 106, 5), // "local"
QT_MOC_LITERAL(10, 112, 14), // "aboutToConnect"
QT_MOC_LITERAL(11, 127, 6), // "remote"
QT_MOC_LITERAL(12, 134, 5), // "bool&"
QT_MOC_LITERAL(13, 140, 4), // "skip"
QT_MOC_LITERAL(14, 145, 9), // "connected"
QT_MOC_LITERAL(15, 155, 6), // "closed"
QT_MOC_LITERAL(16, 162, 10), // "readyWrite"
QT_MOC_LITERAL(17, 173, 16), // "slotReadActivity"
QT_MOC_LITERAL(18, 190, 17), // "slotWriteActivity"
QT_MOC_LITERAL(19, 208, 18) // "lookupFinishedSlot"

    },
    "KNetwork::KClientSocketBase\0stateChanged\0"
    "\0newstate\0gotError\0code\0hostFound\0"
    "bound\0KNetwork::KResolverEntry\0local\0"
    "aboutToConnect\0remote\0bool&\0skip\0"
    "connected\0closed\0readyWrite\0"
    "slotReadActivity\0slotWriteActivity\0"
    "lookupFinishedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNetwork__KClientSocketBase[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       6,    0,   75,    2, 0x06 /* Public */,
       7,    1,   76,    2, 0x06 /* Public */,
      10,    2,   79,    2, 0x06 /* Public */,
      14,    1,   84,    2, 0x06 /* Public */,
      15,    0,   87,    2, 0x06 /* Public */,
      16,    0,   88,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    0,   89,    2, 0x09 /* Protected */,
      18,    0,   90,    2, 0x09 /* Protected */,
      19,    0,   91,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 12,   11,   13,
    QMetaType::Void, 0x80000000 | 8,   11,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KNetwork::KClientSocketBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KClientSocketBase *_t = static_cast<KClientSocketBase *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->gotError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->hostFound(); break;
        case 3: _t->bound((*reinterpret_cast< const KNetwork::KResolverEntry(*)>(_a[1]))); break;
        case 4: _t->aboutToConnect((*reinterpret_cast< const KNetwork::KResolverEntry(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->connected((*reinterpret_cast< const KNetwork::KResolverEntry(*)>(_a[1]))); break;
        case 6: _t->closed(); break;
        case 7: _t->readyWrite(); break;
        case 8: _t->slotReadActivity(); break;
        case 9: _t->slotWriteActivity(); break;
        case 10: _t->lookupFinishedSlot(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KClientSocketBase::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::stateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::gotError)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::hostFound)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)(const KNetwork::KResolverEntry & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::bound)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)(const KNetwork::KResolverEntry & , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::aboutToConnect)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)(const KNetwork::KResolverEntry & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::connected)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::closed)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KClientSocketBase::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KClientSocketBase::readyWrite)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject KNetwork::KClientSocketBase::staticMetaObject = {
    { &KActiveSocketBase::staticMetaObject, qt_meta_stringdata_KNetwork__KClientSocketBase.data,
      qt_meta_data_KNetwork__KClientSocketBase,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNetwork::KClientSocketBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNetwork::KClientSocketBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNetwork__KClientSocketBase.stringdata0))
        return static_cast<void*>(this);
    return KActiveSocketBase::qt_metacast(_clname);
}

int KNetwork::KClientSocketBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KActiveSocketBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KNetwork::KClientSocketBase::stateChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KNetwork::KClientSocketBase::gotError(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KNetwork::KClientSocketBase::hostFound()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KNetwork::KClientSocketBase::bound(const KNetwork::KResolverEntry & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KNetwork::KClientSocketBase::aboutToConnect(const KNetwork::KResolverEntry & _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KNetwork::KClientSocketBase::connected(const KNetwork::KResolverEntry & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KNetwork::KClientSocketBase::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KNetwork::KClientSocketBase::readyWrite()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
