/****************************************************************************
** Meta object code from reading C++ file 'knuminput.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/knuminput.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knuminput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KNumInput_t {
    QByteArrayData data[2];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KNumInput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KNumInput_t qt_meta_stringdata_KNumInput = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KNumInput"
QT_MOC_LITERAL(1, 10, 5) // "label"

    },
    "KNumInput\0label"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KNumInput[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       1,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095103,

       0        // eod
};

void KNumInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        KNumInput *_t = static_cast<KNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KNumInput *_t = static_cast<KNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KNumInput::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KNumInput.data,
      qt_meta_data_KNumInput,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KNumInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNumInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KNumInput.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KNumInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
   if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_KIntNumInput_t {
    QByteArrayData data[24];
    char stringdata0[300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIntNumInput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIntNumInput_t qt_meta_stringdata_KIntNumInput = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KIntNumInput"
QT_MOC_LITERAL(1, 13, 12), // "valueChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 20), // "relativeValueChanged"
QT_MOC_LITERAL(4, 48, 8), // "setValue"
QT_MOC_LITERAL(5, 57, 16), // "setRelativeValue"
QT_MOC_LITERAL(6, 74, 17), // "setReferencePoint"
QT_MOC_LITERAL(7, 92, 9), // "setSuffix"
QT_MOC_LITERAL(8, 102, 6), // "suffix"
QT_MOC_LITERAL(9, 109, 16), // "KLocalizedString"
QT_MOC_LITERAL(10, 126, 9), // "setPrefix"
QT_MOC_LITERAL(11, 136, 6), // "prefix"
QT_MOC_LITERAL(12, 143, 12), // "setEditFocus"
QT_MOC_LITERAL(13, 156, 4), // "mark"
QT_MOC_LITERAL(14, 161, 16), // "spinValueChanged"
QT_MOC_LITERAL(15, 178, 28), // "slotEmitRelativeValueChanged"
QT_MOC_LITERAL(16, 207, 5), // "value"
QT_MOC_LITERAL(17, 213, 7), // "minimum"
QT_MOC_LITERAL(18, 221, 7), // "maximum"
QT_MOC_LITERAL(19, 229, 10), // "singleStep"
QT_MOC_LITERAL(20, 240, 14), // "referencePoint"
QT_MOC_LITERAL(21, 255, 13), // "relativeValue"
QT_MOC_LITERAL(22, 269, 16), // "specialValueText"
QT_MOC_LITERAL(23, 286, 13) // "sliderEnabled"

    },
    "KIntNumInput\0valueChanged\0\0"
    "relativeValueChanged\0setValue\0"
    "setRelativeValue\0setReferencePoint\0"
    "setSuffix\0suffix\0KLocalizedString\0"
    "setPrefix\0prefix\0setEditFocus\0mark\0"
    "spinValueChanged\0slotEmitRelativeValueChanged\0"
    "value\0minimum\0maximum\0singleStep\0"
    "referencePoint\0relativeValue\0"
    "specialValueText\0sliderEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIntNumInput[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
      10,  108, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       3,    1,   77,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   80,    2, 0x0a /* Public */,
       5,    1,   83,    2, 0x0a /* Public */,
       6,    1,   86,    2, 0x0a /* Public */,
       7,    1,   89,    2, 0x0a /* Public */,
       7,    1,   92,    2, 0x0a /* Public */,
      10,    1,   95,    2, 0x0a /* Public */,
      12,    1,   98,    2, 0x0a /* Public */,
      12,    0,  101,    2, 0x2a /* Public | MethodCloned */,
      14,    1,  102,    2, 0x08 /* Private */,
      15,    1,  105,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Double,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, 0x80000000 | 9,    8,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

 // properties: name, type, flags
      16, QMetaType::Int, 0x00595103,
      17, QMetaType::Int, 0x00095103,
      18, QMetaType::Int, 0x00095103,
      19, QMetaType::Int, 0x00095103,
      20, QMetaType::Int, 0x00095103,
      21, QMetaType::Double, 0x00095103,
       8, QMetaType::QString, 0x00095103,
      11, QMetaType::QString, 0x00095103,
      22, QMetaType::QString, 0x00095103,
      23, QMetaType::Bool, 0x00095103,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void KIntNumInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KIntNumInput *_t = static_cast<KIntNumInput *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->relativeValueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 2: _t->setValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->setRelativeValue((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 4: _t->setReferencePoint((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setSuffix((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setSuffix((*reinterpret_cast< const KLocalizedString(*)>(_a[1]))); break;
        case 7: _t->setPrefix((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->setEditFocus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->setEditFocus(); break;
        case 10: _t->spinValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->slotEmitRelativeValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KIntNumInput::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KIntNumInput::valueChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KIntNumInput::*_t)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KIntNumInput::relativeValueChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KIntNumInput *_t = static_cast<KIntNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->value(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->minimum(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->maximum(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->singleStep(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->referencePoint(); break;
        case 5: *reinterpret_cast< double*>(_v) = _t->relativeValue(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->suffix(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->prefix(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->specialValueText(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->showSlider(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KIntNumInput *_t = static_cast<KIntNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setMinimum(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setMaximum(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setSingleStep(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setReferencePoint(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setRelativeValue(*reinterpret_cast< double*>(_v)); break;
        case 6: _t->setSuffix(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setPrefix(*reinterpret_cast< QString*>(_v)); break;
        case 8: _t->setSpecialValueText(*reinterpret_cast< QString*>(_v)); break;
        case 9: _t->setSliderEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KIntNumInput::staticMetaObject = {
    { &KNumInput::staticMetaObject, qt_meta_stringdata_KIntNumInput.data,
      qt_meta_data_KIntNumInput,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIntNumInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIntNumInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIntNumInput.stringdata0))
        return static_cast<void*>(this);
    return KNumInput::qt_metacast(_clname);
}

int KIntNumInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KNumInput::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KIntNumInput::valueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KIntNumInput::relativeValueChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KDoubleNumInput_t {
    QByteArrayData data[25];
    char stringdata0[305];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDoubleNumInput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDoubleNumInput_t qt_meta_stringdata_KDoubleNumInput = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KDoubleNumInput"
QT_MOC_LITERAL(1, 16, 12), // "valueChanged"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 20), // "relativeValueChanged"
QT_MOC_LITERAL(4, 51, 8), // "setValue"
QT_MOC_LITERAL(5, 60, 16), // "setRelativeValue"
QT_MOC_LITERAL(6, 77, 17), // "setReferencePoint"
QT_MOC_LITERAL(7, 95, 3), // "ref"
QT_MOC_LITERAL(8, 99, 9), // "setSuffix"
QT_MOC_LITERAL(9, 109, 6), // "suffix"
QT_MOC_LITERAL(10, 116, 9), // "setPrefix"
QT_MOC_LITERAL(11, 126, 6), // "prefix"
QT_MOC_LITERAL(12, 133, 11), // "sliderMoved"
QT_MOC_LITERAL(13, 145, 14), // "spinBoxChanged"
QT_MOC_LITERAL(14, 160, 28), // "slotEmitRelativeValueChanged"
QT_MOC_LITERAL(15, 189, 5), // "value"
QT_MOC_LITERAL(16, 195, 7), // "minimum"
QT_MOC_LITERAL(17, 203, 7), // "maximum"
QT_MOC_LITERAL(18, 211, 10), // "singleStep"
QT_MOC_LITERAL(19, 222, 16), // "specialValueText"
QT_MOC_LITERAL(20, 239, 8), // "decimals"
QT_MOC_LITERAL(21, 248, 14), // "referencePoint"
QT_MOC_LITERAL(22, 263, 13), // "relativeValue"
QT_MOC_LITERAL(23, 277, 13), // "sliderEnabled"
QT_MOC_LITERAL(24, 291, 13) // "exponentRatio"

    },
    "KDoubleNumInput\0valueChanged\0\0"
    "relativeValueChanged\0setValue\0"
    "setRelativeValue\0setReferencePoint\0"
    "ref\0setSuffix\0suffix\0setPrefix\0prefix\0"
    "sliderMoved\0spinBoxChanged\0"
    "slotEmitRelativeValueChanged\0value\0"
    "minimum\0maximum\0singleStep\0specialValueText\0"
    "decimals\0referencePoint\0relativeValue\0"
    "sliderEnabled\0exponentRatio"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDoubleNumInput[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
      12,   94, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       3,    1,   67,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   70,    2, 0x0a /* Public */,
       5,    1,   73,    2, 0x0a /* Public */,
       6,    1,   76,    2, 0x0a /* Public */,
       8,    1,   79,    2, 0x0a /* Public */,
      10,    1,   82,    2, 0x0a /* Public */,
      12,    1,   85,    2, 0x08 /* Private */,
      13,    1,   88,    2, 0x08 /* Private */,
      14,    1,   91,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    2,

 // properties: name, type, flags
      15, QMetaType::Double, 0x00595103,
      16, QMetaType::Double, 0x00095103,
      17, QMetaType::Double, 0x00095103,
      18, QMetaType::Double, 0x00095103,
       9, QMetaType::QString, 0x00095103,
      11, QMetaType::QString, 0x00095103,
      19, QMetaType::QString, 0x00095103,
      20, QMetaType::Int, 0x00095103,
      21, QMetaType::Double, 0x00095103,
      22, QMetaType::Double, 0x00095103,
      23, QMetaType::Bool, 0x00095103,
      24, QMetaType::Double, 0x00095103,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void KDoubleNumInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KDoubleNumInput *_t = static_cast<KDoubleNumInput *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 1: _t->relativeValueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 2: _t->setValue((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 3: _t->setRelativeValue((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 4: _t->setReferencePoint((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 5: _t->setSuffix((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setPrefix((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->sliderMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->spinBoxChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 9: _t->slotEmitRelativeValueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KDoubleNumInput::*_t)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDoubleNumInput::valueChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KDoubleNumInput::*_t)(double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KDoubleNumInput::relativeValueChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KDoubleNumInput *_t = static_cast<KDoubleNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< double*>(_v) = _t->value(); break;
        case 1: *reinterpret_cast< double*>(_v) = _t->minimum(); break;
        case 2: *reinterpret_cast< double*>(_v) = _t->maximum(); break;
        case 3: *reinterpret_cast< double*>(_v) = _t->singleStep(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->suffix(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->prefix(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->specialValueText(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->decimals(); break;
        case 8: *reinterpret_cast< double*>(_v) = _t->referencePoint(); break;
        case 9: *reinterpret_cast< double*>(_v) = _t->relativeValue(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->showSlider(); break;
        case 11: *reinterpret_cast< double*>(_v) = _t->exponentRatio(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KDoubleNumInput *_t = static_cast<KDoubleNumInput *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValue(*reinterpret_cast< double*>(_v)); break;
        case 1: _t->setMinimum(*reinterpret_cast< double*>(_v)); break;
        case 2: _t->setMaximum(*reinterpret_cast< double*>(_v)); break;
        case 3: _t->setSingleStep(*reinterpret_cast< double*>(_v)); break;
        case 4: _t->setSuffix(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setPrefix(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setSpecialValueText(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setDecimals(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setReferencePoint(*reinterpret_cast< double*>(_v)); break;
        case 9: _t->setRelativeValue(*reinterpret_cast< double*>(_v)); break;
        case 10: _t->setSliderEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setExponentRatio(*reinterpret_cast< double*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KDoubleNumInput::staticMetaObject = {
    { &KNumInput::staticMetaObject, qt_meta_stringdata_KDoubleNumInput.data,
      qt_meta_data_KDoubleNumInput,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDoubleNumInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDoubleNumInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDoubleNumInput.stringdata0))
        return static_cast<void*>(this);
    return KNumInput::qt_metacast(_clname);
}

int KDoubleNumInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KNumInput::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 12;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDoubleNumInput::valueChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDoubleNumInput::relativeValueChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_KIntSpinBox_t {
    QByteArrayData data[4];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIntSpinBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIntSpinBox_t qt_meta_stringdata_KIntSpinBox = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KIntSpinBox"
QT_MOC_LITERAL(1, 12, 12), // "updateSuffix"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 4) // "base"

    },
    "KIntSpinBox\0updateSuffix\0\0base"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIntSpinBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       1,   22, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,

 // properties: name, type, flags
       3, QMetaType::Int, 0x00095103,

       0        // eod
};

void KIntSpinBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KIntSpinBox *_t = static_cast<KIntSpinBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->d->updateSuffix((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KIntSpinBox *_t = static_cast<KIntSpinBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->base(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KIntSpinBox *_t = static_cast<KIntSpinBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBase(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KIntSpinBox::staticMetaObject = {
    { &QSpinBox::staticMetaObject, qt_meta_stringdata_KIntSpinBox.data,
      qt_meta_data_KIntSpinBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIntSpinBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIntSpinBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIntSpinBox.stringdata0))
        return static_cast<void*>(this);
    return QSpinBox::qt_metacast(_clname);
}

int KIntSpinBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSpinBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
