/****************************************************************************
** Meta object code from reading C++ file 'powermanagement_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/solid/powermanagement_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermanagement_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Solid__PowerManagementPrivate_t {
    QByteArrayData data[10];
    char stringdata0[199];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Solid__PowerManagementPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Solid__PowerManagementPrivate_t qt_meta_stringdata_Solid__PowerManagementPrivate = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Solid::PowerManagementPrivate"
QT_MOC_LITERAL(1, 30, 21), // "slotCanSuspendChanged"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 8), // "newState"
QT_MOC_LITERAL(4, 62, 23), // "slotCanHibernateChanged"
QT_MOC_LITERAL(5, 86, 27), // "slotCanHybridSuspendChanged"
QT_MOC_LITERAL(6, 114, 26), // "slotPowerSaveStatusChanged"
QT_MOC_LITERAL(7, 141, 21), // "slotServiceRegistered"
QT_MOC_LITERAL(8, 163, 11), // "serviceName"
QT_MOC_LITERAL(9, 175, 23) // "slotServiceUnregistered"

    },
    "Solid::PowerManagementPrivate\0"
    "slotCanSuspendChanged\0\0newState\0"
    "slotCanHibernateChanged\0"
    "slotCanHybridSuspendChanged\0"
    "slotPowerSaveStatusChanged\0"
    "slotServiceRegistered\0serviceName\0"
    "slotServiceUnregistered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Solid__PowerManagementPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x0a /* Public */,
       4,    1,   47,    2, 0x0a /* Public */,
       5,    1,   50,    2, 0x0a /* Public */,
       6,    1,   53,    2, 0x0a /* Public */,
       7,    1,   56,    2, 0x0a /* Public */,
       9,    1,   59,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,

       0        // eod
};

void Solid::PowerManagementPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PowerManagementPrivate *_t = static_cast<PowerManagementPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotCanSuspendChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->slotCanHibernateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->slotCanHybridSuspendChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->slotPowerSaveStatusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->slotServiceRegistered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotServiceUnregistered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Solid::PowerManagementPrivate::staticMetaObject = {
    { &PowerManagement::Notifier::staticMetaObject, qt_meta_stringdata_Solid__PowerManagementPrivate.data,
      qt_meta_data_Solid__PowerManagementPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Solid::PowerManagementPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::PowerManagementPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Solid__PowerManagementPrivate.stringdata0))
        return static_cast<void*>(this);
    return PowerManagement::Notifier::qt_metacast(_clname);
}

int Solid::PowerManagementPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PowerManagement::Notifier::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
