/****************************************************************************
** Meta object code from reading C++ file 'kcolordialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kcolordialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcolordialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDEPrivate__KColorTable_t {
    QByteArrayData data[14];
    char stringdata0[228];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDEPrivate__KColorTable_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDEPrivate__KColorTable_t qt_meta_stringdata_KDEPrivate__KColorTable = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KDEPrivate::KColorTable"
QT_MOC_LITERAL(1, 24, 13), // "colorSelected"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 18), // "colorDoubleClicked"
QT_MOC_LITERAL(4, 58, 9), // "setColors"
QT_MOC_LITERAL(5, 68, 14), // "collectionName"
QT_MOC_LITERAL(6, 83, 21), // "slotColorCellSelected"
QT_MOC_LITERAL(7, 105, 5), // "index"
QT_MOC_LITERAL(8, 111, 26), // "slotColorCellDoubleClicked"
QT_MOC_LITERAL(9, 138, 21), // "slotColorTextSelected"
QT_MOC_LITERAL(10, 160, 9), // "colorText"
QT_MOC_LITERAL(11, 170, 13), // "slotSetColors"
QT_MOC_LITERAL(12, 184, 15), // "_collectionName"
QT_MOC_LITERAL(13, 200, 27) // "slotShowNamedColorReadError"

    },
    "KDEPrivate::KColorTable\0colorSelected\0"
    "\0colorDoubleClicked\0setColors\0"
    "collectionName\0slotColorCellSelected\0"
    "index\0slotColorCellDoubleClicked\0"
    "slotColorTextSelected\0colorText\0"
    "slotSetColors\0_collectionName\0"
    "slotShowNamedColorReadError"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDEPrivate__KColorTable[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x06 /* Public */,
       3,    2,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   64,    2, 0x0a /* Public */,
       6,    2,   67,    2, 0x08 /* Private */,
       8,    2,   72,    2, 0x08 /* Private */,
       9,    1,   77,    2, 0x08 /* Private */,
      11,    1,   80,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QColor, QMetaType::QString,    2,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    7,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor,    7,    2,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void,

       0        // eod
};

void KDEPrivate::KColorTable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KColorTable *_t = static_cast<KColorTable *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorSelected((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->colorDoubleClicked((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->setColors((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->d->slotColorCellSelected((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 4: _t->d->slotColorCellDoubleClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 5: _t->d->slotColorTextSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->d->slotSetColors((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->d->slotShowNamedColorReadError(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KColorTable::*_t)(const QColor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorTable::colorSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KColorTable::*_t)(const QColor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KColorTable::colorDoubleClicked)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject KDEPrivate::KColorTable::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KDEPrivate__KColorTable.data,
      qt_meta_data_KDEPrivate__KColorTable,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDEPrivate::KColorTable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDEPrivate::KColorTable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDEPrivate__KColorTable.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KDEPrivate::KColorTable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KDEPrivate::KColorTable::colorSelected(const QColor & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDEPrivate::KColorTable::colorDoubleClicked(const QColor & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
