/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p org_kde_solid_networking_client /usr/src/ports/kf5-kdelibs4support/kf5-kdelibs4support-5.43.0-1.x86_64/src/kdelibs4support-5.43.0/src/solid/org.kde.Solid.Networking.Client.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "org_kde_solid_networking_client.h"

/*
 * Implementation of interface class OrgKdeSolidNetworkingClientInterface
 */

OrgKdeSolidNetworkingClientInterface::OrgKdeSolidNetworkingClientInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeSolidNetworkingClientInterface::~OrgKdeSolidNetworkingClientInterface()
{
}


#include "org_kde_solid_networking_client.moc"
