#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kdebugdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KDEBUGDIALOG_H
#define UI_KDEBUGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "ktreewidgetsearchlinewidget.h"

QT_BEGIN_NAMESPACE

class Ui_KDebugDialog
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_5;
    KTreeWidgetSearchLineWidget *m_incrSearch;
    QTreeWidget *m_areaWidget;
    QGroupBox *pInfoGroup;
    QFormLayout *formLayout;
    QLabel *label_2;
    KComboBox *pInfoCombo;
    QLabel *label_3;
    KLineEdit *pInfoFile;
    QGroupBox *pErrorGroup;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    KComboBox *pErrorCombo;
    QLabel *label_9;
    KLineEdit *pErrorFile;
    QCheckBox *pAbortFatal;
    QSpacerItem *verticalSpacer;
    QCheckBox *m_disableAll2;
    QGroupBox *pWarnGroup;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    KComboBox *pWarnCombo;
    QLabel *label_5;
    KLineEdit *pWarnFile;
    QGroupBox *pFatalGroup;
    QFormLayout *formLayout_4;
    QLabel *label_6;
    KComboBox *pFatalCombo;
    QLabel *label_7;
    KLineEdit *pFatalFile;

    void setupUi(QWidget *KDebugDialog)
    {
        if (KDebugDialog->objectName().isEmpty())
            KDebugDialog->setObjectName(QStringLiteral("KDebugDialog"));
        KDebugDialog->resize(481, 447);
        gridLayout = new QGridLayout(KDebugDialog);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        m_incrSearch = new KTreeWidgetSearchLineWidget(KDebugDialog);
        m_incrSearch->setObjectName(QStringLiteral("m_incrSearch"));

        verticalLayout_5->addWidget(m_incrSearch);

        m_areaWidget = new QTreeWidget(KDebugDialog);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QStringLiteral("1"));
        m_areaWidget->setHeaderItem(__qtreewidgetitem);
        m_areaWidget->setObjectName(QStringLiteral("m_areaWidget"));
        m_areaWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        m_areaWidget->setRootIsDecorated(false);
        m_areaWidget->setUniformRowHeights(true);
        m_areaWidget->setItemsExpandable(false);
        m_areaWidget->header()->setVisible(false);

        verticalLayout_5->addWidget(m_areaWidget);


        gridLayout->addLayout(verticalLayout_5, 1, 0, 7, 1);

        pInfoGroup = new QGroupBox(KDebugDialog);
        pInfoGroup->setObjectName(QStringLiteral("pInfoGroup"));
        formLayout = new QFormLayout(pInfoGroup);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label_2 = new QLabel(pInfoGroup);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_2);

        pInfoCombo = new KComboBox(pInfoGroup);
        pInfoCombo->setObjectName(QStringLiteral("pInfoCombo"));

        formLayout->setWidget(0, QFormLayout::FieldRole, pInfoCombo);

        label_3 = new QLabel(pInfoGroup);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_3);

        pInfoFile = new KLineEdit(pInfoGroup);
        pInfoFile->setObjectName(QStringLiteral("pInfoFile"));

        formLayout->setWidget(1, QFormLayout::FieldRole, pInfoFile);


        gridLayout->addWidget(pInfoGroup, 1, 1, 1, 1);

        pErrorGroup = new QGroupBox(KDebugDialog);
        pErrorGroup->setObjectName(QStringLiteral("pErrorGroup"));
        formLayout_3 = new QFormLayout(pErrorGroup);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        label_8 = new QLabel(pErrorGroup);
        label_8->setObjectName(QStringLiteral("label_8"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, label_8);

        pErrorCombo = new KComboBox(pErrorGroup);
        pErrorCombo->setObjectName(QStringLiteral("pErrorCombo"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, pErrorCombo);

        label_9 = new QLabel(pErrorGroup);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, label_9);

        pErrorFile = new KLineEdit(pErrorGroup);
        pErrorFile->setObjectName(QStringLiteral("pErrorFile"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, pErrorFile);


        gridLayout->addWidget(pErrorGroup, 3, 1, 1, 1);

        pAbortFatal = new QCheckBox(KDebugDialog);
        pAbortFatal->setObjectName(QStringLiteral("pAbortFatal"));

        gridLayout->addWidget(pAbortFatal, 5, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 1, 1, 1);

        m_disableAll2 = new QCheckBox(KDebugDialog);
        m_disableAll2->setObjectName(QStringLiteral("m_disableAll2"));

        gridLayout->addWidget(m_disableAll2, 0, 0, 1, 2);

        pWarnGroup = new QGroupBox(KDebugDialog);
        pWarnGroup->setObjectName(QStringLiteral("pWarnGroup"));
        formLayout_2 = new QFormLayout(pWarnGroup);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        label_4 = new QLabel(pWarnGroup);
        label_4->setObjectName(QStringLiteral("label_4"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, label_4);

        pWarnCombo = new KComboBox(pWarnGroup);
        pWarnCombo->setObjectName(QStringLiteral("pWarnCombo"));

        formLayout_2->setWidget(0, QFormLayout::FieldRole, pWarnCombo);

        label_5 = new QLabel(pWarnGroup);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_5);

        pWarnFile = new KLineEdit(pWarnGroup);
        pWarnFile->setObjectName(QStringLiteral("pWarnFile"));

        formLayout_2->setWidget(1, QFormLayout::FieldRole, pWarnFile);


        gridLayout->addWidget(pWarnGroup, 2, 1, 1, 1);

        pFatalGroup = new QGroupBox(KDebugDialog);
        pFatalGroup->setObjectName(QStringLiteral("pFatalGroup"));
        formLayout_4 = new QFormLayout(pFatalGroup);
        formLayout_4->setObjectName(QStringLiteral("formLayout_4"));
        label_6 = new QLabel(pFatalGroup);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout_4->setWidget(0, QFormLayout::LabelRole, label_6);

        pFatalCombo = new KComboBox(pFatalGroup);
        pFatalCombo->setObjectName(QStringLiteral("pFatalCombo"));

        formLayout_4->setWidget(0, QFormLayout::FieldRole, pFatalCombo);

        label_7 = new QLabel(pFatalGroup);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout_4->setWidget(1, QFormLayout::LabelRole, label_7);

        pFatalFile = new KLineEdit(pFatalGroup);
        pFatalFile->setObjectName(QStringLiteral("pFatalFile"));

        formLayout_4->setWidget(1, QFormLayout::FieldRole, pFatalFile);


        gridLayout->addWidget(pFatalGroup, 4, 1, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        label_2->setBuddy(pInfoCombo);
        label_3->setBuddy(pInfoFile);
        label_8->setBuddy(pErrorCombo);
        label_9->setBuddy(pErrorFile);
        label_4->setBuddy(pWarnCombo);
        label_5->setBuddy(pWarnFile);
        label_6->setBuddy(pFatalCombo);
        label_7->setBuddy(pFatalFile);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(m_disableAll2, m_areaWidget);
        QWidget::setTabOrder(m_areaWidget, pInfoCombo);
        QWidget::setTabOrder(pInfoCombo, pInfoFile);
        QWidget::setTabOrder(pInfoFile, pWarnCombo);
        QWidget::setTabOrder(pWarnCombo, pWarnFile);
        QWidget::setTabOrder(pWarnFile, pErrorCombo);
        QWidget::setTabOrder(pErrorCombo, pErrorFile);
        QWidget::setTabOrder(pErrorFile, pFatalCombo);
        QWidget::setTabOrder(pFatalCombo, pFatalFile);
        QWidget::setTabOrder(pFatalFile, pAbortFatal);

        retranslateUi(KDebugDialog);

        QMetaObject::connectSlotsByName(KDebugDialog);
    } // setupUi

    void retranslateUi(QWidget *KDebugDialog)
    {
        pInfoGroup->setTitle(tr2i18n("Information", Q_NULLPTR));
        label_2->setText(tr2i18n("Output to:", Q_NULLPTR));
        label_3->setText(tr2i18n("Filename:", Q_NULLPTR));
        pErrorGroup->setTitle(tr2i18n("Error", Q_NULLPTR));
        label_8->setText(tr2i18n("Output to:", Q_NULLPTR));
        label_9->setText(tr2i18n("Filename:", Q_NULLPTR));
        pAbortFatal->setText(tr2i18n("Abort on fatal errors", Q_NULLPTR));
        m_disableAll2->setText(tr2i18n("Disable all debug output", Q_NULLPTR));
        pWarnGroup->setTitle(tr2i18n("Warning", Q_NULLPTR));
        label_4->setText(tr2i18n("Output to:", Q_NULLPTR));
        label_5->setText(tr2i18n("Filename:", Q_NULLPTR));
        pFatalGroup->setTitle(tr2i18n("Fatal Error", Q_NULLPTR));
        label_6->setText(tr2i18n("Output to:", Q_NULLPTR));
        label_7->setText(tr2i18n("Filename:", Q_NULLPTR));
        Q_UNUSED(KDebugDialog);
    } // retranslateUi

};

namespace Ui {
    class KDebugDialog: public Ui_KDebugDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KDEBUGDIALOG_H

