/****************************************************************************
** Meta object code from reading C++ file 'keditlistbox.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/keditlistbox.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keditlistbox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KEditListBox_t {
    QByteArrayData data[23];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KEditListBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KEditListBox_t qt_meta_stringdata_KEditListBox = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KEditListBox"
QT_MOC_LITERAL(1, 13, 7), // "changed"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 5), // "added"
QT_MOC_LITERAL(4, 28, 4), // "text"
QT_MOC_LITERAL(5, 33, 7), // "removed"
QT_MOC_LITERAL(6, 41, 10), // "moveItemUp"
QT_MOC_LITERAL(7, 52, 12), // "moveItemDown"
QT_MOC_LITERAL(8, 65, 7), // "addItem"
QT_MOC_LITERAL(9, 73, 10), // "removeItem"
QT_MOC_LITERAL(10, 84, 17), // "enableMoveButtons"
QT_MOC_LITERAL(11, 102, 14), // "typedSomething"
QT_MOC_LITERAL(12, 117, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(13, 138, 14), // "QItemSelection"
QT_MOC_LITERAL(14, 153, 8), // "selected"
QT_MOC_LITERAL(15, 162, 10), // "deselected"
QT_MOC_LITERAL(16, 173, 7), // "buttons"
QT_MOC_LITERAL(17, 181, 7), // "Buttons"
QT_MOC_LITERAL(18, 189, 5), // "items"
QT_MOC_LITERAL(19, 195, 3), // "Add"
QT_MOC_LITERAL(20, 199, 6), // "Remove"
QT_MOC_LITERAL(21, 206, 6), // "UpDown"
QT_MOC_LITERAL(22, 213, 3) // "All"

    },
    "KEditListBox\0changed\0\0added\0text\0"
    "removed\0moveItemUp\0moveItemDown\0addItem\0"
    "removeItem\0enableMoveButtons\0"
    "typedSomething\0slotSelectionChanged\0"
    "QItemSelection\0selected\0deselected\0"
    "buttons\0Buttons\0items\0Add\0Remove\0"
    "UpDown\0All"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KEditListBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       2,   88, // properties
       1,   96, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    1,   65,    2, 0x06 /* Public */,
       5,    1,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   71,    2, 0x09 /* Protected */,
       7,    0,   72,    2, 0x09 /* Protected */,
       8,    0,   73,    2, 0x09 /* Protected */,
       9,    0,   74,    2, 0x09 /* Protected */,
      10,    2,   75,    2, 0x09 /* Protected */,
      11,    1,   80,    2, 0x09 /* Protected */,
      12,    2,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QString,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    2,    2,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 13, 0x80000000 | 13,   14,   15,

 // properties: name, type, flags
      16, 0x80000000 | 17, 0x0009510b,
      18, QMetaType::QStringList, 0x00595103,

 // properties: notify_signal_id
       0,
       0,

 // enums: name, flags, count, data
      17, 0x1,    4,  100,

 // enum data: key, value
      19, uint(KEditListBox::Add),
      20, uint(KEditListBox::Remove),
      21, uint(KEditListBox::UpDown),
      22, uint(KEditListBox::All),

       0        // eod
};

void KEditListBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KEditListBox *_t = static_cast<KEditListBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->added((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->removed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->moveItemUp(); break;
        case 4: _t->moveItemDown(); break;
        case 5: _t->addItem(); break;
        case 6: _t->removeItem(); break;
        case 7: _t->enableMoveButtons((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 8: _t->typedSomething((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotSelectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KEditListBox::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KEditListBox::changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KEditListBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KEditListBox::added)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KEditListBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KEditListBox::removed)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KEditListBox *_t = static_cast<KEditListBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = QFlag(_t->buttons()); break;
        case 1: *reinterpret_cast< QStringList*>(_v) = _t->items(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KEditListBox *_t = static_cast<KEditListBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setButtons(QFlag(*reinterpret_cast<int*>(_v))); break;
        case 1: _t->setItems(*reinterpret_cast< QStringList*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KEditListBox::staticMetaObject = {
    { &QGroupBox::staticMetaObject, qt_meta_stringdata_KEditListBox.data,
      qt_meta_data_KEditListBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KEditListBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KEditListBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KEditListBox.stringdata0))
        return static_cast<void*>(this);
    return QGroupBox::qt_metacast(_clname);
}

int KEditListBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGroupBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KEditListBox::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KEditListBox::added(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KEditListBox::removed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
