/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p org_kde_solid_networking_client /usr/src/ports/kf5-kdelibs4support/kf5-kdelibs4support-5.43.0-1.x86_64/src/kdelibs4support-5.43.0/src/solid/org.kde.Solid.Networking.Client.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ORG_KDE_SOLID_NETWORKING_CLIENT_H
#define ORG_KDE_SOLID_NETWORKING_CLIENT_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Solid.Networking.Client
 */
class OrgKdeSolidNetworkingClientInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Solid.Networking.Client"; }

public:
    OrgKdeSolidNetworkingClientInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeSolidNetworkingClientInterface();

    Q_PROPERTY(uint Status READ status)
    inline uint status() const
    { return qvariant_cast< uint >(property("Status")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<uint> status()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("status"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void statusChanged(uint in0);
};

namespace org {
  namespace kde {
    namespace Solid {
      namespace Networking {
        typedef ::OrgKdeSolidNetworkingClientInterface Client;
      }
    }
  }
}
#endif
