/****************************************************************************
** Meta object code from reading C++ file 'kapplication.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kapplication.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KApplication_t {
    QByteArrayData data[17];
    char stringdata0[232];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KApplication_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KApplication_t qt_meta_stringdata_KApplication = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KApplication"
QT_MOC_LITERAL(1, 13, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 29, 20), // "org.kde.KApplication"
QT_MOC_LITERAL(3, 50, 12), // "saveYourself"
QT_MOC_LITERAL(4, 63, 0), // ""
QT_MOC_LITERAL(5, 64, 19), // "updateUserTimestamp"
QT_MOC_LITERAL(6, 84, 4), // "time"
QT_MOC_LITERAL(7, 89, 10), // "commitData"
QT_MOC_LITERAL(8, 100, 16), // "QSessionManager&"
QT_MOC_LITERAL(9, 117, 2), // "sm"
QT_MOC_LITERAL(10, 120, 9), // "saveState"
QT_MOC_LITERAL(11, 130, 20), // "reparseConfiguration"
QT_MOC_LITERAL(12, 151, 4), // "quit"
QT_MOC_LITERAL(13, 156, 21), // "_k_x11FilterDestroyed"
QT_MOC_LITERAL(14, 178, 28), // "_k_slot_KToolInvocation_hook"
QT_MOC_LITERAL(15, 207, 12), // "QStringList&"
QT_MOC_LITERAL(16, 220, 11) // "QByteArray&"

    },
    "KApplication\0D-Bus Interface\0"
    "org.kde.KApplication\0saveYourself\0\0"
    "updateUserTimestamp\0time\0commitData\0"
    "QSessionManager&\0sm\0saveState\0"
    "reparseConfiguration\0quit\0"
    "_k_x11FilterDestroyed\0"
    "_k_slot_KToolInvocation_hook\0QStringList&\0"
    "QByteArray&"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KApplication[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       9,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   61,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   62,    4, 0x4a /* Public | isScriptable */,
       5,    0,   65,    4, 0x6a /* Public | MethodCloned | isScriptable */,
       7,    1,   66,    4, 0x0a /* Public */,
      10,    1,   69,    4, 0x0a /* Public */,
      11,    0,   72,    4, 0x4a /* Public | isScriptable */,
      12,    0,   73,    4, 0x4a /* Public | isScriptable */,
      13,    0,   74,    4, 0x08 /* Private */,
      14,    2,   75,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15, 0x80000000 | 16,    4,    4,

       0        // eod
};

void KApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KApplication *_t = static_cast<KApplication *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->saveYourself(); break;
        case 1: _t->updateUserTimestamp((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->updateUserTimestamp(); break;
        case 3: _t->commitData((*reinterpret_cast< QSessionManager(*)>(_a[1]))); break;
        case 4: _t->saveState((*reinterpret_cast< QSessionManager(*)>(_a[1]))); break;
        case 5: _t->reparseConfiguration(); break;
        case 6: _t->quit(); break;
        case 7: _t->d->_k_x11FilterDestroyed(); break;
        case 8: _t->d->_k_slot_KToolInvocation_hook((*reinterpret_cast< QStringList(*)>(_a[1])),(*reinterpret_cast< QByteArray(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KApplication::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KApplication::saveYourself)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KApplication::staticMetaObject = {
    { &QApplication::staticMetaObject, qt_meta_stringdata_KApplication.data,
      qt_meta_data_KApplication,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KApplication.stringdata0))
        return static_cast<void*>(this);
    return QApplication::qt_metacast(_clname);
}

int KApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KApplication::saveYourself()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
