/****************************************************************************
** Meta object code from reading C++ file 'kdirselectdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kio/kdirselectdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdirselectdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDirSelectDialog_t {
    QByteArrayData data[13];
    char stringdata0[185];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDirSelectDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDirSelectDialog_t qt_meta_stringdata_KDirSelectDialog = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KDirSelectDialog"
QT_MOC_LITERAL(1, 17, 13), // "setCurrentUrl"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 3), // "url"
QT_MOC_LITERAL(4, 36, 18), // "slotCurrentChanged"
QT_MOC_LITERAL(5, 55, 10), // "slotExpand"
QT_MOC_LITERAL(6, 66, 16), // "slotUrlActivated"
QT_MOC_LITERAL(7, 83, 20), // "slotComboTextChanged"
QT_MOC_LITERAL(8, 104, 24), // "slotContextMenuRequested"
QT_MOC_LITERAL(9, 129, 13), // "slotNewFolder"
QT_MOC_LITERAL(10, 143, 15), // "slotMoveToTrash"
QT_MOC_LITERAL(11, 159, 10), // "slotDelete"
QT_MOC_LITERAL(12, 170, 14) // "slotProperties"

    },
    "KDirSelectDialog\0setCurrentUrl\0\0url\0"
    "slotCurrentChanged\0slotExpand\0"
    "slotUrlActivated\0slotComboTextChanged\0"
    "slotContextMenuRequested\0slotNewFolder\0"
    "slotMoveToTrash\0slotDelete\0slotProperties"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDirSelectDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x0a /* Public */,
       4,    0,   67,    2, 0x08 /* Private */,
       5,    1,   68,    2, 0x08 /* Private */,
       6,    1,   71,    2, 0x08 /* Private */,
       7,    1,   74,    2, 0x08 /* Private */,
       8,    1,   77,    2, 0x08 /* Private */,
       9,    0,   80,    2, 0x08 /* Private */,
      10,    0,   81,    2, 0x08 /* Private */,
      11,    0,   82,    2, 0x08 /* Private */,
      12,    0,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KDirSelectDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KDirSelectDialog *_t = static_cast<KDirSelectDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setCurrentUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->d->slotCurrentChanged(); break;
        case 2: _t->d->slotExpand((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->d->slotUrlActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->d->slotComboTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->d->slotContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 6: _t->d->slotNewFolder(); break;
        case 7: _t->d->slotMoveToTrash(); break;
        case 8: _t->d->slotDelete(); break;
        case 9: _t->d->slotProperties(); break;
        default: ;
        }
    }
}

const QMetaObject KDirSelectDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KDirSelectDialog.data,
      qt_meta_data_KDirSelectDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KDirSelectDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDirSelectDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDirSelectDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KDirSelectDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
