/****************************************************************************
** Meta object code from reading C++ file 'klistwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/klistwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'klistwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KListWidget_t {
    QByteArrayData data[12];
    char stringdata0[159];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KListWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KListWidget_t qt_meta_stringdata_KListWidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KListWidget"
QT_MOC_LITERAL(1, 12, 8), // "executed"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(4, 39, 4), // "item"
QT_MOC_LITERAL(5, 44, 3), // "pos"
QT_MOC_LITERAL(6, 48, 13), // "doubleClicked"
QT_MOC_LITERAL(7, 62, 18), // "_k_slotItemEntered"
QT_MOC_LITERAL(8, 81, 17), // "_k_slotOnViewport"
QT_MOC_LITERAL(9, 99, 22), // "_k_slotSettingsChanged"
QT_MOC_LITERAL(10, 122, 17), // "_k_slotAutoSelect"
QT_MOC_LITERAL(11, 140, 18) // "_k_slotEmitExecute"

    },
    "KListWidget\0executed\0\0QListWidgetItem*\0"
    "item\0pos\0doubleClicked\0_k_slotItemEntered\0"
    "_k_slotOnViewport\0_k_slotSettingsChanged\0"
    "_k_slotAutoSelect\0_k_slotEmitExecute"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KListWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       1,    2,   57,    2, 0x06 /* Public */,
       6,    2,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   67,    2, 0x08 /* Private */,
       8,    0,   70,    2, 0x08 /* Private */,
       9,    1,   71,    2, 0x08 /* Private */,
      10,    0,   74,    2, 0x08 /* Private */,
      11,    1,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QPoint,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QPoint,    4,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void KListWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KListWidget *_t = static_cast<KListWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->executed((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 1: _t->executed((*reinterpret_cast< QListWidgetItem*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 2: _t->doubleClicked((*reinterpret_cast< QListWidgetItem*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 3: _t->d->_k_slotItemEntered((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 4: _t->d->_k_slotOnViewport(); break;
        case 5: _t->d->_k_slotSettingsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->d->_k_slotAutoSelect(); break;
        case 7: _t->d->_k_slotEmitExecute((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KListWidget::*_t)(QListWidgetItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KListWidget::executed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KListWidget::*_t)(QListWidgetItem * , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KListWidget::executed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KListWidget::*_t)(QListWidgetItem * , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KListWidget::doubleClicked)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KListWidget::staticMetaObject = {
    { &QListWidget::staticMetaObject, qt_meta_stringdata_KListWidget.data,
      qt_meta_data_KListWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KListWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KListWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KListWidget.stringdata0))
        return static_cast<void*>(this);
    return QListWidget::qt_metacast(_clname);
}

int KListWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KListWidget::executed(QListWidgetItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KListWidget::executed(QListWidgetItem * _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KListWidget::doubleClicked(QListWidgetItem * _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
