/****************************************************************************
** Meta object code from reading C++ file 'kglobalsettings.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kdelibs4support-5.43.0/src/kdeui/kglobalsettings.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kglobalsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KGlobalSettings_t {
    QByteArrayData data[17];
    char stringdata0[261];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KGlobalSettings_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KGlobalSettings_t qt_meta_stringdata_KGlobalSettings = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KGlobalSettings"
QT_MOC_LITERAL(1, 16, 22), // "kdisplayPaletteChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 20), // "kdisplayStyleChanged"
QT_MOC_LITERAL(4, 61, 19), // "kdisplayFontChanged"
QT_MOC_LITERAL(5, 81, 17), // "appearanceChanged"
QT_MOC_LITERAL(6, 99, 24), // "toolbarAppearanceChanged"
QT_MOC_LITERAL(7, 124, 15), // "settingsChanged"
QT_MOC_LITERAL(8, 140, 8), // "category"
QT_MOC_LITERAL(9, 149, 11), // "iconChanged"
QT_MOC_LITERAL(10, 161, 5), // "group"
QT_MOC_LITERAL(11, 167, 13), // "cursorChanged"
QT_MOC_LITERAL(12, 181, 14), // "blockShortcuts"
QT_MOC_LITERAL(13, 196, 4), // "data"
QT_MOC_LITERAL(14, 201, 21), // "naturalSortingChanged"
QT_MOC_LITERAL(15, 223, 19), // "_k_slotNotifyChange"
QT_MOC_LITERAL(16, 243, 17) // "_k_slotIconChange"

    },
    "KGlobalSettings\0kdisplayPaletteChanged\0"
    "\0kdisplayStyleChanged\0kdisplayFontChanged\0"
    "appearanceChanged\0toolbarAppearanceChanged\0"
    "settingsChanged\0category\0iconChanged\0"
    "group\0cursorChanged\0blockShortcuts\0"
    "data\0naturalSortingChanged\0"
    "_k_slotNotifyChange\0_k_slotIconChange"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KGlobalSettings[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,
       3,    0,   75,    2, 0x06 /* Public */,
       4,    0,   76,    2, 0x06 /* Public */,
       5,    0,   77,    2, 0x06 /* Public */,
       6,    1,   78,    2, 0x06 /* Public */,
       7,    1,   81,    2, 0x06 /* Public */,
       9,    1,   84,    2, 0x16 /* Public | MethodCompatibility */,
      11,    0,   87,    2, 0x06 /* Public */,
      12,    1,   88,    2, 0x06 /* Public */,
      14,    0,   91,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    2,   92,    2, 0x08 /* Private */,
      16,    1,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void KGlobalSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KGlobalSettings *_t = static_cast<KGlobalSettings *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->kdisplayPaletteChanged(); break;
        case 1: _t->kdisplayStyleChanged(); break;
        case 2: _t->kdisplayFontChanged(); break;
        case 3: _t->appearanceChanged(); break;
        case 4: _t->toolbarAppearanceChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->settingsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->iconChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->cursorChanged(); break;
        case 8: _t->blockShortcuts((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->naturalSortingChanged(); break;
        case 10: _t->d->_k_slotNotifyChange((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->d->_k_slotIconChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::kdisplayPaletteChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::kdisplayStyleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::kdisplayFontChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::appearanceChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::toolbarAppearanceChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::settingsChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::iconChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::cursorChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::blockShortcuts)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KGlobalSettings::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KGlobalSettings::naturalSortingChanged)) {
                *result = 9;
                return;
            }
        }
    }
}

const QMetaObject KGlobalSettings::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KGlobalSettings.data,
      qt_meta_data_KGlobalSettings,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KGlobalSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KGlobalSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KGlobalSettings.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KGlobalSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KGlobalSettings::kdisplayPaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KGlobalSettings::kdisplayStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KGlobalSettings::kdisplayFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KGlobalSettings::appearanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KGlobalSettings::toolbarAppearanceChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KGlobalSettings::settingsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KGlobalSettings::iconChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KGlobalSettings::cursorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KGlobalSettings::blockShortcuts(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KGlobalSettings::naturalSortingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
