#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'displaycert.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DISPLAYCERT_H
#define UI_DISPLAYCERT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ksslcertificatebox.h"

QT_BEGIN_NAMESPACE

class Ui_DisplayCert
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *subjectHeading;
    KSslCertificateBox *subjectCertBox;
    QLabel *issuerHeading;
    KSslCertificateBox *issuerCertBox;
    QLabel *label;
    QFormLayout *formLayout;
    QLabel *validityPeriodLabel;
    QLabel *validityPeriod;
    QLabel *serialNumberLabel;
    QLabel *serialNumber;
    QLabel *md5DigestLabel;
    QLabel *md5Digest;
    QLabel *sha1DigestLabel;
    QLabel *sha1Digest;

    void setupUi(QWidget *DisplayCert)
    {
        if (DisplayCert->objectName().isEmpty())
            DisplayCert->setObjectName(QStringLiteral("DisplayCert"));
        DisplayCert->resize(374, 479);
        verticalLayout = new QVBoxLayout(DisplayCert);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        subjectHeading = new QLabel(DisplayCert);
        subjectHeading->setObjectName(QStringLiteral("subjectHeading"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(subjectHeading->sizePolicy().hasHeightForWidth());
        subjectHeading->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(subjectHeading);

        subjectCertBox = new KSslCertificateBox(DisplayCert);
        subjectCertBox->setObjectName(QStringLiteral("subjectCertBox"));

        verticalLayout->addWidget(subjectCertBox);

        issuerHeading = new QLabel(DisplayCert);
        issuerHeading->setObjectName(QStringLiteral("issuerHeading"));
        sizePolicy.setHeightForWidth(issuerHeading->sizePolicy().hasHeightForWidth());
        issuerHeading->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(issuerHeading);

        issuerCertBox = new KSslCertificateBox(DisplayCert);
        issuerCertBox->setObjectName(QStringLiteral("issuerCertBox"));

        verticalLayout->addWidget(issuerCertBox);

        label = new QLabel(DisplayCert);
        label->setObjectName(QStringLiteral("label"));
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(label);

        formLayout = new QFormLayout();
        formLayout->setObjectName(QStringLiteral("formLayout"));
        validityPeriodLabel = new QLabel(DisplayCert);
        validityPeriodLabel->setObjectName(QStringLiteral("validityPeriodLabel"));

        formLayout->setWidget(0, QFormLayout::LabelRole, validityPeriodLabel);

        validityPeriod = new QLabel(DisplayCert);
        validityPeriod->setObjectName(QStringLiteral("validityPeriod"));

        formLayout->setWidget(0, QFormLayout::FieldRole, validityPeriod);

        serialNumberLabel = new QLabel(DisplayCert);
        serialNumberLabel->setObjectName(QStringLiteral("serialNumberLabel"));

        formLayout->setWidget(1, QFormLayout::LabelRole, serialNumberLabel);

        serialNumber = new QLabel(DisplayCert);
        serialNumber->setObjectName(QStringLiteral("serialNumber"));

        formLayout->setWidget(1, QFormLayout::FieldRole, serialNumber);

        md5DigestLabel = new QLabel(DisplayCert);
        md5DigestLabel->setObjectName(QStringLiteral("md5DigestLabel"));

        formLayout->setWidget(2, QFormLayout::LabelRole, md5DigestLabel);

        md5Digest = new QLabel(DisplayCert);
        md5Digest->setObjectName(QStringLiteral("md5Digest"));

        formLayout->setWidget(2, QFormLayout::FieldRole, md5Digest);

        sha1DigestLabel = new QLabel(DisplayCert);
        sha1DigestLabel->setObjectName(QStringLiteral("sha1DigestLabel"));

        formLayout->setWidget(3, QFormLayout::LabelRole, sha1DigestLabel);

        sha1Digest = new QLabel(DisplayCert);
        sha1Digest->setObjectName(QStringLiteral("sha1Digest"));

        formLayout->setWidget(3, QFormLayout::FieldRole, sha1Digest);


        verticalLayout->addLayout(formLayout);


        retranslateUi(DisplayCert);

        QMetaObject::connectSlotsByName(DisplayCert);
    } // setupUi

    void retranslateUi(QWidget *DisplayCert)
    {
        subjectHeading->setText(tr2i18n("<b>Subject Information</b>", Q_NULLPTR));
        issuerHeading->setText(tr2i18n("<b>Issuer Information</b>", Q_NULLPTR));
        label->setText(tr2i18n("<b>Other</b>", Q_NULLPTR));
        validityPeriodLabel->setText(tr2i18n("Validity period", Q_NULLPTR));
        validityPeriod->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        serialNumberLabel->setText(tr2i18n("Serial number", Q_NULLPTR));
        serialNumber->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        md5DigestLabel->setText(tr2i18n("MD5 digest", Q_NULLPTR));
        md5Digest->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        sha1DigestLabel->setText(tr2i18n("SHA1 digest", Q_NULLPTR));
        sha1Digest->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        Q_UNUSED(DisplayCert);
    } // retranslateUi

};

namespace Ui {
    class DisplayCert: public Ui_DisplayCert {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DISPLAYCERT_H

