/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a serviceadaptor -i networkstatus.h -l NetworkStatusModule /usr/src/ports/kf5-kdelibs4support/kf5-kdelibs4support-5.43.0-1.x86_64/src/kdelibs4support-5.43.0/src/solid-networkstatus/org.kde.Solid.Networking.Service.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "serviceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ServiceAdaptor
 */

ServiceAdaptor::ServiceAdaptor(NetworkStatusModule *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ServiceAdaptor::~ServiceAdaptor()
{
    // destructor
}

QStringList ServiceAdaptor::networks()
{
    // handle method call org.kde.Solid.Networking.Service.networks
    return parent()->networks();
}

void ServiceAdaptor::registerNetwork(const QString &networkName, int status, const QString &serviceName)
{
    // handle method call org.kde.Solid.Networking.Service.registerNetwork
    parent()->registerNetwork(networkName, status, serviceName);
}

void ServiceAdaptor::setNetworkStatus(const QString &networkName, int status)
{
    // handle method call org.kde.Solid.Networking.Service.setNetworkStatus
    parent()->setNetworkStatus(networkName, status);
}

void ServiceAdaptor::unregisterNetwork(const QString &networkName)
{
    // handle method call org.kde.Solid.Networking.Service.unregisterNetwork
    parent()->unregisterNetwork(networkName);
}


#include "serviceadaptor.moc"
